@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
-"""
-downloads Orbit files from various sources
-"""
 import argparse
+import numpy as np
 import sys
+import time
 
 import gnssrefl.gps as g
 
@@ -24,7 +23,21 @@ def parse_arguments():
 
 def download_orbits(orbit: str, year: int, month: int, day: int, doy_end: int = None ):
     """
-    command line interface for download_orbits
+    command line interface for download_orbits. If day is zero, then it is assumed that 
+    the month record is day or year
+
+    Examples
+    --------
+    download_orbits nav 2020 50 0
+        downloads broadcast orbits for day of year 50 in the year 2020
+    download_orbits nav 2020 1 1 
+        downloads broadcast orbits for January 1, 2020
+    download_orbits gnss 2023 1 1 
+        multi-GNSS orbits from GFZ
+    download_orbits rapid 2023 1 1 
+        rapid multi-GNSS orbits from GFZ
+    download_orbits rapid 2023 1 0 -doy_end 10
+        rapid multi-GNSS orbits from GFZ for days of year 1 thru 10 in 2023
 
     Parameters
     ----------
@@ -36,7 +49,7 @@ def download_orbits(orbit: str, year: int, month: int, day: int, doy_end: int =
 
             gps+glo : will use JAXA orbits which have GPS and Glonass (usually available in 48 hours)
 
-            gnss : will use GFZ orbits, which is multi-GNSS (available in 3-4 days)
+            gnss : will use GFZ orbits, which is multi-GNSS (available in 3-4 days). but taken from CDDIS archive
 
             nav : GPS broadcast, adequate for reflectometry. Searches various places
 
@@ -62,7 +75,9 @@ def download_orbits(orbit: str, year: int, month: int, day: int, doy_end: int =
 
             wum : (disabled) Wuhan, multi-GNSS, not rapid
 
-            gnss2 : multi-GNSS, but uses IGN instead of CDDIS
+            gnss2 : multi-GNSS, but uses IGN instead of CDDIS. does not work
+
+            gnss3 : multi-GNSS, but uses GFZ archive instead of CDDIS. same as gnss-gfz
 
             ultra : ultra orbits directly from GFZ
 
@@ -70,13 +85,10 @@ def download_orbits(orbit: str, year: int, month: int, day: int, doy_end: int =
 
     year : integer
         full year
-
     month : integer
         calendar month
-
     day : integer
         day of the month
-
     doy_end : integer 
         optional, allows multiple day download
 
@@ -85,8 +97,8 @@ def download_orbits(orbit: str, year: int, month: int, day: int, doy_end: int =
 #   make sure environment variables exist.  set to current directory if not
     g.check_environ_variables()
 
-    orbit_list = ['igs', 'igr', 'jax', 'grg', 'wum', 'gbm', 'nav', 'gps', 'gps+glo', 'gnss', 'gfr', 'esa', 'gnss2', 'ultra', 'rapid','nav-esa', 'nav-sopac','nav-cddis']
-
+    orbit_list = ['igs', 'igr', 'jax', 'grg', 'wum', 'gbm', 'nav', 'gps', 'gps+glo', 
+            'gnss', 'gfr', 'esa', 'gnss2', 'gnss3','gnss-gfz','ultra', 'rapid','nav-esa', 'nav-sopac','nav-cddis']
 
 #   assign to normal variables
     pCtr = orbit
@@ -108,7 +120,7 @@ def download_orbits(orbit: str, year: int, month: int, day: int, doy_end: int =
     if pCtr == 'gps':
         pCtr = 'nav'
 
-    # this is picked up from CDDIS
+    # send to CDDIS to get final GFZ orbits
     if pCtr == 'gnss':
         pCtr = 'gbm'
 
@@ -121,8 +133,10 @@ def download_orbits(orbit: str, year: int, month: int, day: int, doy_end: int =
 
     d1= int(doy); d2 = int(doy_end) + 1
     for d in range(d1, d2):
+        s1 = time.time()
 
         year,month,day= g.ydoy2ymd(year,d)
+        print('Looking for ', year, '/', d, ' mm/dd', month, day)
         if (pCtr == 'nav'):
             navname, navdir, foundit = g.getnavfile(year, month, day)
             if foundit:
@@ -152,8 +166,12 @@ def download_orbits(orbit: str, year: int, month: int, day: int, doy_end: int =
                 elif pCtr == 'ultra':
                     hour = 0 # for now only download hour 0 for ultra products
                     filename, fdir, foundit = g.ultra_gfz_orbits(year, month, day, hour)
+                elif (pCtr == 'gnss3') or (pCtr == 'gnss-gfz'):
+                # use GFZ archive instead of CDDIS
+                    filename, fdir, foundit = g.gbm_orbits_direct(year, month, day)
                 elif pCtr == 'gnss2':
                 # use IGN instead of CDDIS
+                    print('To my knowledge, this option no longer works')
                     filename, fdir, foundit = g.avoid_cddis(year, month, day)
                 else:
                     filename, fdir, foundit = g.getsp3file_mgex(year, month, day, pCtr)
@@ -161,6 +179,8 @@ def download_orbits(orbit: str, year: int, month: int, day: int, doy_end: int =
                 print('SUCCESS:', fdir+'/'+filename)
             else:
                 print(filename, ' not found')
+        s2 = time.time()
+        print('That download took ', np.round(s2-s1,2), ' seconds')
 
 
 def main():
