@@ -21,53 +21,49 @@ def parse_arguments():
     parser.add_argument("day", help="day (zero if you use day of year earlier)", type=int)
     # optional arguments
     parser.add_argument("-rate", default='low', metavar='low', type=str, help="sample rate: low or high")
-    parser.add_argument("-archive", default=None, 
-                        help="archive (unavco,sopac,cddis,sonel,nz,ga,ngs,bkg,nrcan)", type=str)
+    parser.add_argument("-archive", default=None, help="archive name", type=str)
     parser.add_argument("-version", default=None, metavar=2, type=int, help="rinex version (2 or 3)")
-    parser.add_argument("-strip", default=None, type=str,
-                        help="set to True to strip to only SNR observables, gfzrnx used")
+    parser.add_argument("-strip", default=None, type=str, help="set to True to strip to only SNR observables, gfzrnx used")
     parser.add_argument("-doy_end", default=None, type=int, help="last day of year to be downloaded")
-    parser.add_argument("-stream", default=None, type=str,
-                        help="set to True to get stream-defined Rinex3 filename. I know. I know. It is annoying.")
+    parser.add_argument("-stream", default=None, type=str, help="set to S get stream-defined Rinex3 filename. Default is R. ")
     parser.add_argument("-samplerate", default=None, type=int, help="Sample rate in seconds. For RINEX3 only.")
-    parser.add_argument("-debug", default=None, type=str, help="debugging flag for printout. default is False")
+    parser.add_argument("-screenstats", default=None, type=str, help="debugging flag for printout. default is False")
     parser.add_argument("-dec", default=None, type=int, help="decimation value (seconds). Only for RINEX 3.")
     parser.add_argument("-save_crx", default=None, type=str, help="Save crx version. Only for RINEX 3.")
-    parser.add_argument("-bkg", default=None, type=str, help="bkg directory, only for highrate RINEX 3.")
 
     args = parser.parse_args().__dict__
 
     # convert all expected boolean inputs from strings to booleans
-    boolean_args = ['strip','debug','save_crx']
+    boolean_args = ['strip','screenstats','save_crx']
     args = str2bool(args, boolean_args)
 
     # only return a dictionary of arguments that were added from the user - all other defaults will be set in code below
     return {key: value for key, value in args.items() if value is not None}
 
 
-def download_rinex(station: str, year: int, month: int, day: int, rate: str = 'low', archive: str = None,
-                   version: int = 2, strip: bool = False, doy_end: 
-                   int = None, stream: str = 'R', samplerate: int = 30, 
-                   debug: bool = False, dec: int = 1, save_crx: bool = False, bkg: str = None ):
+def download_rinex(station: str, year: int, month: int, day: int, rate: str = 'low', archive: str = 'all',
+                   version: int = 2, strip: bool = False, doy_end: int = None, stream: str = 'R', samplerate: int = 30, 
+                   screenstats : bool = False, dec: int = 1, save_crx: bool = False ):
     """
     Command line interface for downloading RINEX files from global archives.
-    Required inputs are station, year, month, and day.
+    Required inputs are station, year, month, and day. If you want to use day of year,
+    call it as station, year, doy, 0.
 
-    Example:
+    decimate does not seem to do anything, at least not for RINEX 2.11 files
+
+    bkg option is changed.  now must specify bkg-igs or bkg-euref
+
+    Examples
+    --------
 
     download_rinex mfle 2015 1 1 
-
-    If you want to download using day of year instead of month/day:
+        downloads January 1, 2015
 
     download_rinex mfle 2015 52 0
-
-    RINEX 2.11 Files
-
-    If you want to specify an archive:
+        Using day of year instead of month/day:
 
     download_rinex p101 2015 52 0 -archive sopac
-
-    RINEX 3 instructions need to be added.
+        checks only sopac archive
 
     Parameters
     ----------
@@ -75,13 +71,13 @@ def download_rinex(station: str, year: int, month: int, day: int, rate: str = 'l
         4 or 9 character ID of the station.
 
     year : int
-        Year
+        full Year
 
     month : int
         month
 
     day : int
-        day
+        day of month
 
     rate : str, optional
         sample rate. value options:
@@ -94,37 +90,43 @@ def download_rinex(station: str, year: int, month: int, day: int, rate: str = 'l
         Select which archive to get the files from.
         Default is redirected to all, as defined below. Value options:
 
-            unavco : now earthscope
-
-            sonel : (global sea level observing system)
-
-            sopac : (Scripps Orbit and Permanent Array Center)
-
-            cddis : (NASA's Archive of Space Geodesy Data)
-
-            ngs : (National Geodetic Survey)
-
-            nrcan : (Natural Resources Canada)
-
-            bkg : (German Agency for Cartography and Geodesy)
-
-            bfg : (German Agency for water research, only Rinex 3)
-
-            nz : (GNS, New Zealand)
-
-            ga : (Geoscience Australia)
+            cddis : (NASA)
 
             bev : (Austria Federal Office of Metrology and Surveying)
 
+            bkg-igs : igs folder of BKG (German Agency for Cartography and Geodesy)
+
+            bkg-euref : Euref folder of BKG (German Agency for Cartography and Geodesy)
+
+            bfg : (German Agency for water research, only Rinex 3)
+
+            ga : (Geoscience Australia)
+
+            gfz : (GFZ)
+
+            jp : (Japan)
+
             jeff : Jeff Freymueller
 
+            nrcan : (Natural Resources Canada)
+
+            ngs : (National Geodetic Survey)
+
+            nz : (GNS, New Zealand)
+
+            sonel : (?)
+
+            sopac : (Scripps Orbit and Permanent Array Center)
+
             special : (reflectometry Rinex 2.11 files maintained by unavco)
 
-            all : (searches sopac, unavco, and sonel in that order)
+            unavco : now earthscope
+
+            all : (searches unavco, sopac, and sonel in that order)
 
     version : int, optional
         Version of Rinex file. Default is 2.
-        Value options  2 or 3 
+        Value options 2 or 3 
 
     strip : bool, optional
         Whether to strip only SNR observables.  Uses teqc or gfzrnx.
@@ -135,14 +137,14 @@ def download_rinex(station: str, year: int, month: int, day: int, rate: str = 'l
         Default is None. (meaning only a single day using the doy parameter)
 
     stream : str, optional
-        Whether to get stream 'S' defined filenames.
-        Default is 'R'. 
+        Receiver or stream file, for RINEX3 only
+        Default is 'R' but you can set to 'S' to get streamed version
 
     samplerate : int, optional
         Sample rate in seconds for RINEX3 only.
         Default is 30.
 
-    debug : bool, optional
+    screenstats : bool, optional
         provides screen output helpful for debugging
         Default is False
 
@@ -152,18 +154,25 @@ def download_rinex(station: str, year: int, month: int, day: int, rate: str = 'l
     save_crx : bool, option
         saves crx version for Rinex3 downloads. Otherwise they are deleted.
 
-    bkg : str, optional
-        tells you which directory the files live in, EUREF or IGS
-        Default is EUREF.
     """
 
 #   make sure environment variables exist.  set to current directory if not
-    g.check_environ_variables()
 
-    if bkg is None:
-        bkg = 'EUREF'
-    else:
-        bkg = bkg.upper()
+    g.check_environ_variables()
+    debug = screenstats
+
+
+    if 'bkg' in archive:
+        if (archive == 'bkg'):
+            print('You have not specified which BKG archive you want.')
+            print('You must select bkg-igs or bkg-euref.')
+            sys.exit()
+        if 'euref' in archive:
+            bkg = 'EUREF'
+        else:
+            bkg = 'IGS'
+        # change archive name back to original
+        archive = 'bkg'
 
     if len(str(year)) != 4:
         print('Year must have four characters: ', year)
@@ -172,15 +181,16 @@ def download_rinex(station: str, year: int, month: int, day: int, rate: str = 'l
     month, day, doy, cyyyy, cyy, cdoy = g.ymd2ch(year,month,day)
 
     # allowed archives, rinex 2.11
-    # unavco2 is for testing
-    archive_list = ['sopac', 'unavco', 'sonel', 'cddis', 'nz', 'ga', 
-            'bkg', 'jeff', 'ngs', 'nrcan', 'special', 'bev', 'all','unavco2']
+    # not really sure bev, gfz, bkg work ???
+    archive_list = ['bkg','bfg','bev','cddis', 'ga', 'gfz', 'jeff', 'ngs', 
+            'nrcan', 'nz','sonel','sopac','special', 'unavco', 'all','unavco2']
 
     # removed the all archive
-    archive_list_high = ['unavco', 'nrcan', 'cddis','ga','bkg']  # though it is confusing because some are rinex 2.11 and others 3
+    # removed cddis because it is too slow
+    archive_list_high = ['bkg','unavco', 'nrcan', 'ga']  # though it is confusing because some are rinex 2.11 and others 3
 
     # archive list for rinex3 lowrate files
-    archive_list_rinex3 = ['unavco', 'cddis', 'ga', 'bev', 'bkg', 'ign', 'epn', 'bfg','sonel','all','unavco2','nrcan','gfz']
+    archive_list_rinex3 = ['unavco', 'bkg','cddis', 'ga', 'bev', 'ign', 'epn', 'bfg','sonel','all','unavco2','nrcan','gfz']
 
     if doy_end is None:
         doy_end = doy
@@ -243,7 +253,7 @@ def download_rinex(station: str, year: int, month: int, day: int, rate: str = 'l
             sys.exit()
 
     if (rate == 'high') and (version == 3):
-        if ((archive == 'cddis') or (archive == 'bkg')) or (archive == 'ga'):
+        if (archive == 'bkg') or (archive == 'ga'):
             print('Highrate RINEX 3 is supported - but it is very slow. Pick up a cup of coffee.')
         else:
             print('I do not support RINEX 3 high rate downloads from your selected archive.')
@@ -255,20 +265,23 @@ def download_rinex(station: str, year: int, month: int, day: int, rate: str = 'l
             print('Request ', station, year, d, archive, samplerate, stream)
             if rate == 'high':
                 if archive == 'cddis':
-                    print('seek highrate data at CDDIS')
+                    if debug:
+                        print('seek highrate data at CDDIS')
                     ch.cddis_highrate(station, year, d, 0, stream, 1)
                 if archive == 'bkg':                               
-                    print('seek highrate data at BKG')
+                    if debug:
+                        print('seek highrate data at BKG')
                     rnx_filename,foundit = ch.bkg_highrate(station, year, d, 0,stream,dec,bkg)
                 if archive == 'ga':
-                    print('seek highrate data at GA')
+                    if debug:
+                        print('seek highrate data at GA')
                     deleteOld = True
                     r2, foundit = g.ga_highrate(station,year,d,dec,deleteOld)
             else:
                 if archive == 'all':
-                    file_name, foundit = k.universal_all(station, year, d, samplerate, stream)
+                    file_name, foundit = k.universal_all(station, year, d, samplerate, stream,debug)
                     if not foundit:
-                        file_name, foundit = k.universal_all(station, year, d, samplerate, k.swapRS(stream))
+                        file_name, foundit = k.universal_all(station, year, d, samplerate, k.swapRS(stream),debug)
                 else:
                     file_name, foundit = k.universal(station, year, d, archive, samplerate, stream,debug)
                     if not foundit:
@@ -281,6 +294,9 @@ def download_rinex(station: str, year: int, month: int, day: int, rate: str = 'l
                         # i do not think this was doing what we thought it was doing ....
                         #subprocess.call(['rm', '-f', new_file_name.replace('rnx', 'crx')])  # delete crx file
                         print('\n SUCCESS 2: ', new_file_name)
+                else:
+                    print('Unsuccessful RINEX 3 retrieval')
+
         else:  # RINEX VERSION 2
             # using new karnak code
             rinexfile, rinexfiled = g.rinex_name(station, year, d, 0)
@@ -289,12 +305,13 @@ def download_rinex(station: str, year: int, month: int, day: int, rate: str = 'l
             else:
                 if archive == 'all':
                     foundit = False
-                    print('cycle thru unavco,sopac,sonel archives')
+                    if debug:
+                        print('cycle thru unavco,sopac,sonel archives')
                     for archiveinput in ['unavco', 'sopac', 'sonel']:
                         if not foundit:
-                            file_name, foundit = k.universal_rinex2(station, year, d, archiveinput)
+                            file_name, foundit = k.universal_rinex2(station, year, d, archiveinput,debug)
                 else:
-                    file_name, foundit = k.universal_rinex2(station, year, d, archive)
+                    file_name, foundit = k.universal_rinex2(station, year, d, archive, debug)
                 if foundit:  # uncompress and make o files ...
                     rinexfile, foundit = k.make_rinex2_ofiles(file_name)  # translate
 
