@@ -149,8 +149,12 @@ def universal(station9ch, year, doy, archive,srate,stream,debug=False):
 
     """
     # define the file name
-    print('Searching the ', archive, ' archive with rate/filetype', srate, stream)
+    if debug:
+        print('Searching the ', archive, ' archive with rate/filetype', srate, stream)
     foundit = False
+    dtmp, month, day, cyyyy,cdoy, YMD = g.ydoy2useful(year,doy)
+    cmm = '{:02d}'.format(month)
+    cdd = '{:02d}'.format(day)
 
     file_name,cyyyy,cdoy = filename_plus(station9ch,year,doy,srate,stream)
     print('Filename:', file_name)
@@ -161,9 +165,20 @@ def universal(station9ch, year, doy, archive,srate,stream,debug=False):
     # put this outside the try because I think there is one in the function
     if archive == 'bfg':
         station = station9ch[0:4] ; samplerate = srate; stream = 'R'
+        debug = False
         g.bfg_data(station, year, doy, samplerate,debug)
+        zip_file_name = file_name[0:-2] + 'zip'
         if os.path.exists(file_name):
-            print('File was found: ', file_name )
+            if debug:
+                print('File was found: ', file_name )
+            foundit = True
+        elif os.path.exists(zip_file_name):
+            if debug:
+                print('From zip to gz: ', zip_file_name )
+            subprocess.call(['unzip', zip_file_name])
+            subprocess.call(['gzip', file_name[0:-3]])
+            # cleaning up
+            subprocess.call(['rm', zip_file_name])
             foundit = True
         else:
             print('File was not found: at bfg.')
@@ -175,10 +190,10 @@ def universal(station9ch, year, doy, archive,srate,stream,debug=False):
         # original dir1 = 'https://data.unavco.org/archive/gnss/rinex3/obs/' + cyyyy + '/' + cdoy + '/'
         #url1 =      'https://data-idm.unavco.org/archive/gnss/rinex3/obs/' + cydoy + file_name
         url1 =      'https://data.unavco.org/archive/gnss/rinex3/obs/' + cydoy + file_name
-        print('Testing new unavco protocols:',url1)
         foundit,file_name = kelly.the_kelly_simple_way(url1,file_name)
         s2 = time.time()
-        print('Download took ',np.round(s2-s1,2), ' seconds') 
+        if debug:
+            print('Download took ',np.round(s2-s1,2), ' seconds') 
         return file_name,foundit
 
     try:
@@ -197,6 +212,12 @@ def universal(station9ch, year, doy, archive,srate,stream,debug=False):
             dir1 = 'https://epncb.oma.be/ftp/obs/' + cyyyy + '/' + cdoy + '/'
             print(dir1)
             wget.download(dir1+file_name,file_name)
+        elif (archive == 'ignes'):
+           # if someone wanted to help by adding this to the high rate
+           # https://datos-geodesia.ign.es/ERGNSS/horario_1s/YYYYMMDD/HH/file
+            dir1 = 'https://datos-geodesia.ign.es/ERGNSS/diario_30s/' + cyyyy + '/' + cyyyy + cmm + cdd + '/'
+            #print(dir1)
+            wget.download(dir1+file_name,file_name)
         elif (archive == 'ga'):
             QUERY_PARAMS, headers = ga_stuff(station9ch, year, doy)
             API_URL = 'https://data.gnss.ga.gov.au/api/rinexFiles/'  
@@ -217,18 +238,18 @@ def universal(station9ch, year, doy, archive,srate,stream,debug=False):
         elif (archive == 'gfz'):
             # no idea
             dir1 = 'ftp://isdcftp.gfz-potsdam.de/gnss/data/daily/' + cyyyy + '/' + cdoy + '/'
-            print(dir1+file_name)
+            #print(dir1+file_name)
             wget.download(dir1+file_name,file_name)
         elif (archive == 'cddis'):
             new_way_dir = '/gnss/data/daily/' + cyyyy + '/' + cdoy + '/' + cyy + 'd/'
             g.cddis_download_2022B(file_name,new_way_dir)
-            #g.cddis_download(file_name,new_way_dir)
         else:
             return '', ''
     except:
         okokok = 1
     s2 = time.time()
-    print('Download took ',np.round(s2-s1,2), ' seconds') 
+    if debug: 
+        print('Download took ',np.round(s2-s1,2), ' seconds') 
     if os.path.exists(file_name):
         siz = os.path.getsize(file_name)
         if (siz == 0):
@@ -327,7 +348,7 @@ def ga_stuff(station, year, doy,rinexv=3):
 
     return QUERY_PARAMS, headers
 
-def universal_all(station9ch, year, doy, srate,stream):
+def universal_all(station9ch, year, doy, srate,stream,screenstats):
     """
     check multiple archives for RINEX 3 data
 
@@ -343,6 +364,8 @@ def universal_all(station9ch, year, doy, srate,stream):
         receiver sample rate 
     stream : str
         R or S
+    screenstats : bool
+        print statements
 
     Peturns
     -------
@@ -381,7 +404,7 @@ def rinex2names(station,year,doy):
         day of year
 
     Results
-    --------
+    -------
     f1 : str
         hatanaka rinex filename
     f2 : str
@@ -401,27 +424,28 @@ def rinex2names(station,year,doy):
     return f1, f2, cyyyy, cdoy
 
 
-def universal_rinex2(station, year, doy, archive):
+def universal_rinex2(station, year, doy, archive,screenstats):
     """
     seamless archive for rinex 2 files ...
 
     Parameters
     ----------
-    station : string
+    station : str
         four character station name
-    year : integer
-
-    doy : integer
-
-    archive : string
+    year : int
+        full year
+    doy : int
+        day of year
+    archive : str
         name of the GNSS archive
+    screenstats : bool
+        whether print statements come to scree
 
     Returns
     -------
-    file_name : string
+    file_name : str
         filename that was downloaded
-
-    foundit : boolean
+    foundit : bool
         whether file was found
 
     """
@@ -434,7 +458,8 @@ def universal_rinex2(station, year, doy, archive):
         #print('RINEX o File is already on disk')
         return oname, True 
 
-    print('Searching the ', archive, ' archive for ', station)
+    if screenstats:
+        print('Searching the ', archive, ' archive for ', station)
 
     cydoy = cyyyy + '/' + cdoy + '/'
     cyy = cyyyy[2:4]
@@ -452,17 +477,22 @@ def universal_rinex2(station, year, doy, archive):
         if not foundit:
             foundit, file_name = gogetit(dir1, oname, '.Z')
     elif (archive == 'unavco'):
-        print('testing out new protocol at unavco')
         #url1 = 'https://data-idm.unavco.org/archive/gnss/rinex/obs/' + cydoy + dname + '.Z'
         url1 = 'https://data.unavco.org/archive/gnss/rinex/obs/' + cydoy + dname + '.Z'
+        print(url1)
         foundit,file_name = kelly.the_kelly_simple_way(url1, dname + '.Z')
         if not foundit:
             url2 = 'https://data.unavco.org/archive/gnss/rinex/obs/' + cydoy + oname + '.Z'
+            print(url2)
             foundit,file_name = kelly.the_kelly_simple_way(url2, oname + '.Z')
-
     elif (archive == 'special'):
-        dir1 = 'https://data.unavco.org/archive/gnss/products/reflectometry/' + cydoy
-        foundit, file_name = gogetit(dir1, oname, '.gz'); 
+        #print('testing out new protocol at unavco')
+        url1 = 'https://data.unavco.org/archive/gnss/products/reflectometry/' + cydoy + oname + '.gz'
+        if screenstats:
+            print(url1)
+        foundit,file_name = kelly.the_kelly_simple_way(url1, oname + '.gz')
+        # old way
+        #foundit, file_name = gogetit(dir1, oname, '.gz'); 
     elif archive == 'sopac':
         dir1 = 'ftp://garner.ucsd.edu/pub/rinex/' + cydoy
         foundit, file_name = gogetit(dir1, dname, '.Z');
@@ -518,13 +548,15 @@ def universal_rinex2(station, year, doy, archive):
         dir1 = 'ftp://cacsa.nrcan.gc.ca/gps/data/gpsdata/' + cyy + cdoy  + '/' + cyy + 'd' + '/'
         foundit, f = gogetit(dir1, dname, '.Z'); file_name = f
     else:
-         print('I do not recognize your archive')
+         print('I do not recognize your archive', archive)
 
     s2 = time.time()
-    print('Download took ', np.round(s2-s1,2),' seconds') 
+    if screenstats:
+        print('Download took ', np.round(s2-s1,2),' seconds') 
 
-    if not os.path.exists(file_name):
+    if not os.path.exists(file_name) and screenstats:
         print('Did not find the Rinex file')
+
     return file_name,foundit
 
 def make_rinex2_ofiles(file_name):
@@ -575,7 +607,8 @@ def make_rinex2_ofiles(file_name):
 
 def strip_rinexfile(rinexfile):
     """
-    uses either teqc or gfzrnx to reduce observables
+    uses either teqc or gfzrnx to reduce observables,
+    i.e. only SNR data.
 
     Parameters
     ----------
@@ -585,7 +618,7 @@ def strip_rinexfile(rinexfile):
     print('You chose the strip option to reduce the number of observables in the RINEX file')
     teqcv = g.teqc_version()
     if os.path.isfile(teqcv):
-        print('Use teqc to strip the RINEX 2 file')
+        #print('Use teqc to strip the RINEX 2 file')
         foutname = 'tmp.' + rinexfile
         fout = open(foutname,'w')
         subprocess.call([teqcv, '-O.obs','S1+S2+S5+S6+S7+S8', rinexfile],stdout=fout)
@@ -595,7 +628,7 @@ def strip_rinexfile(rinexfile):
     else:
         gfzrnxpath = g.gfz_version()
         if os.path.isfile(gfzrnxpath):
-            print('Use gfzrnx to strip the RINEX 2 file')
+            #print('Use gfzrnx to strip the RINEX 2 file')
             tempfile = rinexfile + '.tmp'
             # save yourself heartache down the way cause those doppler data are just clogging up the works
             subprocess.call([gfzrnxpath,'-finp', rinexfile, '-fout', tempfile, '-vo','2','-f', '-obs_types', 'S','-q'])
@@ -720,7 +753,7 @@ def ga_stuff_highrate(station, year, doy,rinexv=3):
 
 def serial_cddis_files(dname,cyyyy,cdoy):
     """
-    only looks in the hatanaka decompression section of cddis
+    Looks for rinex files in the hatanaka decompression section of cddis
 
     Parameters
     ----------
