@@ -9,6 +9,7 @@ import gnssrefl.gps as g
 import gnssrefl.read_snr_files as read_snr
 from gnssrefl.utils import FileManagement, FileTypes
 import gnssrefl.daily_avg_cl as da
+import gnssrefl.gnssir_v2 as gnssir
 
 from functools import partial
 from scipy import optimize
@@ -45,32 +46,31 @@ def normAmp(amp, basepercent):
 
     return Namp
 
-def daily_phase_plot(station, fr,datetime_dates, tv,xdir,subdir):
+def daily_phase_plot(station, fr,datetime_dates, tv,xdir,subdir,hires_figs):
     """
-    makes a plot of daily averaged phase
+    makes a plot of daily averaged phase for vwc code
 
     Parameters
     ----------
     station: str
-        4 char station
-
+        4 char station name
     fr : int
-        frequency
-
+        frequency of signal
     datetime_dates : ...
-
+        datetime values for phase points
     tv : list of results
-
+        cannot remember the format
     xdir : str
         location of the results (environment variable REFL_CODE)
-
     subdir : str
         subdirectory in Files
+    hires_figs: bool
+        whether you want eps instead of png files
 
     """
     outdir = xdir + '/Files/' + subdir
     plt.figure(figsize=(10, 6))
-    plt.plot(datetime_dates, tv[:, 2], 'bo')
+    plt.plot(datetime_dates, tv[:, 2], 'b-')
     plt.ylabel('phase (degrees)')
     if fr == 1:
         plt.title(f"Daily L1 Phase Results: {station.upper()}")
@@ -80,51 +80,67 @@ def daily_phase_plot(station, fr,datetime_dates, tv,xdir,subdir):
     plt.gcf().autofmt_xdate()
 
     # maybe this works.  Maybe not.
-    plot_path = f'{outdir}/{station}_daily_phase.png'
+    if hires_figs:
+        plot_path = f'{outdir}/{station}_daily_phase.eps'
+    else:
+        plot_path = f'{outdir}/{station}_daily_phase.png'
     print(f"Saving figure to {plot_path}")
+
     plt.savefig(plot_path)
 
 
 
 def make_snow_filter(station, medfilter, ReqTracks, year1, year2):
     """
-    runs daily_avg code so you have some idea of when the soil moisture products are 
-    contaminated by snow. make a file with these years and doys saved
+    Runs daily_avg code to make a snow mask file.  This is 
+    so you have some idea of when the soil moisture products are 
+    contaminated by snow. Make a file with these years and doys saved. The user can
+    edit if they feel the suggestsions are poor (i.e. days in the summer might show up
+    as "snow")
+
+    If snow mask file exists, it does not overwrite it.
 
     Parameters
     ----------
     station : str
         4 ch station name
-
     medfilter : float
         how much you allow the individual tracks to deviate from the daily median (meters)
-
-    ReqTracks : integer
+    ReqTracks : int
         number of tracks to compute trustworthy daily average
-
-    year1 : integer
+    year1 : int
         starting year
-
-    year2 : integer
+    year2 : int
         ending year
 
     Returns
     -------
-    snowmask_exists : boolean
+    snowmask_exists : bool
+        whether file was created
+    snow_file : str
+        name of the snow mask file
 
-    creates output file into a file $REFL_CODE/Files/snowmask_{ssss}.txt
+    Creates output file into a file $REFL_CODE/Files/{ssss}/snowmask_{ssss}.txt
+    where ssss is the station name
 
     """
+    snowmask_exists = False
     myxdir = os.environ['REFL_CODE']
+    snowfile = myxdir + '/Files/' + station + '/snowmask_' + station + '.txt' 
+    if os.path.exists(snowfile):
+        print('Using existing snow mask file, ', snowfile)
+        snowmask_exists = True
+        return snowmask_exists,snowfile
+
     # l2c only
-    txtfile = 'test_' + station + '.txt'; 
+    txtfile = station + '_allRH.txt'; 
     pltit = False; extension = ''; fr = 20; csv = False
 
     # writes out a daily average file. woudl be better if it returned the values, but this works
     da.daily_avg(station, medfilter, ReqTracks, txtfile, pltit,
               extension, year1, year2, fr, csv) 
-
     avgf = myxdir + '/Files/' + station + '/' + txtfile
+    print('Looking in ', avgf)
     x = np.loadtxt(avgf, comments='%')
     # delete the file!
     rh = x[:,2]
@@ -134,7 +150,6 @@ def make_snow_filter(station, medfilter, ReqTracks, year1, year2):
     ii = (rh -medianvalue) < -0.05
     newx = x[ii,:] ; N=len(newx)
     if (N > 0):
-        snowfile = myxdir + '/Files/' + station + 'snowmask_' + station + '.txt' 
         print('Suspect snow values stored in : ', snowfile)
         snow = open(snowfile, 'w+')
         for i in range(0,N):
@@ -142,14 +157,16 @@ def make_snow_filter(station, medfilter, ReqTracks, year1, year2):
             print('Suspect Snow Day : ', int(newx[i,0]), int(newx[i,1]))
             snow.write("{0:4.0f}  {1:3.0f} {2:8.3f}  \n".format( newx[i,0], newx[i,1], sv))
         snow.close()
-    # now that you saved what you need from daily average file, delete it.
-
+    subprocess.call(['rm','-f',avgf])
+    if os.path.exists(snowfile):
         snowmask_exists = True
     else:
-        snowmask_exists = False
-    subprocess.call(['rm',avgf])
+        print('I tried to make a snow mask file for you - but it did not work. This is most likely because ')
+        print('this is a limited site, i.e. fewer tracks than the code wants. Go ahead and make one by hand,')
+        print('plain text of year,doy is all you need ', snowfile)
+        snowfile = None
 
-    return snowmask_exists
+    return snowmask_exists, snowfile
 
 def vwc_plot(station,t_datetime, vwcdata, plot_path,circles):
     """
@@ -191,9 +208,9 @@ def vwc_plot(station,t_datetime, vwcdata, plot_path,circles):
     else:
         plt.plot(t_datetime, vwcdata, 'b-')
         plt.plot(t_datetime, vwcdata, 'b.')
-    plt.title('GNSS Station ' + station.upper())
+    plt.title('GNSS-IR Soil Moisture Station ' + station.upper())
     plt.ylim(0, 0.5)
-    plt.ylabel('Vol. Soil Moisture')
+    plt.ylabel('Volumetric Soil Moisture')
     plt.grid()
     plt.gcf().autofmt_xdate()
 
@@ -304,35 +321,26 @@ def phase_tracks(station, year, doy, snr_type, fr_list, e1, e2, pele, plot, scre
     ----------
     station name : string
         4 char id, lowercase
-    year : integer
-
-    doy : integer
+    year : int
+        calendar year
+    doy : int
         day of year
-
-    snr_type : integer
-        is the file extension (i.e. 99, 66 etc)
-
+    snr_type : int
+        SNR file extension (i.e. 99, 66 etc)
     fr_list : list of integers
         frequency, [1], [20] or [1,20] 
-
     e1 : float
         min elevation angle (degrees)
-
     e2 : float 
         max elevation angle (degrees)
-
     pele : list of floats 
         elevation angle limits for the polynomial removal.  units: degrees
-
-    screenstats : boolean
+    screenstats : bool
         whether statistics are printed to the screen
-
-    compute_lsp : boolean
-        this is always true
-
-    gzip : boolean
+    compute_lsp : bool
+        this is always true for now
+    gzip : bool
         whether you want SNR files gzipped after running the code
-
     Only GPS frequencies are allowed because this relies on the repeating ground track.
 
     """
@@ -352,6 +360,7 @@ def phase_tracks(station, year, doy, snr_type, fr_list, e1, e2, pele, plot, scre
     # noise region - hardwired for normal sites ~ 2-3 meters tall
     noise_region = [0.5, 8]
 
+    l2c_list, l5_sat = g.l2c_l5_list(year,doy)
 
     if not snrexist:
         print('No SNR file on this day.')
@@ -375,7 +384,9 @@ def phase_tracks(station, year, doy, snr_type, fr_list, e1, e2, pele, plot, scre
                 rows, columns = np.shape(apriori_results)
 
                 for i in range(0, rows):
+                    compute_lsp = True # will set to false for non-compliant L2C requests
                     azim = apriori_results[i, 3]
+                    # this will be the satellite number you are working on 
                     sat_number = apriori_results[i, 2]
                     az1 = apriori_results[i, 5]
                     az2 = apriori_results[i, 6]
@@ -384,13 +395,17 @@ def phase_tracks(station, year, doy, snr_type, fr_list, e1, e2, pele, plot, scre
                     x, y, nv, cf, utctime, avg_azim, avg_edot, edot2, del_t = g.window_data(s1, s2, s5, s6, s7, s8, sat, ele, azi,
                                                                                         t, edot, freq, az1, az2, e1, e2,
                                                                                         sat_number, poly_v, pele, screenstats)
+                    if (freq == 20) and (sat_number not in l2c_list) :
+                        if screenstats: 
+                            print('Asked for L2C but this is not L2C transmitting on this day: ', int(sat_number))
+                        compute_lsp = False
+
                     if screenstats:
                         print(f'Track {i:2.0f} Sat {sat_number:3.0f} Azimuth {azim:5.1f} RH {rh_apriori:6.2f} {nv:5.0f}')
 
-                    if compute_lsp and nv > min_num_pts:
-                        min_height = 0.5
-                        max_height = 8
-                        desired_p = 0.01
+                    if compute_lsp and (nv > min_num_pts):
+                        # this is the same every track, so no reason to be in the loop
+                        min_height = 0.5 ; max_height = 8 ; desired_p = 0.01
 
                         max_f, max_amp, emin_obs, emax_obs, rise_set, px, pz = g.strip_compute(x, y, cf, max_height,
                                                                                            desired_p, poly_v, min_height)
@@ -460,7 +475,8 @@ def low_pct(amp, basepercent):
     return lowval
 
 
-def convert_phase(station, year, year_end=None, plt2screen=True,fr=20,tmin=0.05,tmax=0.5,polyorder=-99,circles=False,subdir=''):
+def convert_phase(station, year, year_end=None, plt2screen=True,fr=20,tmin=0.05,tmax=0.5,polyorder=-99,circles=False,
+        subdir='',hires_figs=False):
     """
     Convert GPS phase to VWC. Using Clara Chew's algorithm from 
     Matlab write_vegcorrect_smc.m
@@ -480,17 +496,18 @@ def convert_phase(station, year, year_end=None, plt2screen=True,fr=20,tmin=0.05,
     fr : integer
         frequency
         default is L2C (20)
+    tmin : float
+        soil texture minimum
+    tmax : float
+        soil texture maximum
     polyorder : integer
         override on the polynomial order used in leveling
     circles : boolean
         final plot using circles (instead of line)
     subdir : str
-        subdirector for $REFL_CODE/Files
-    tmin : float
-        soil texture minimum
-    tmax : float
-        soil texture maximum
-
+        subdirectory for $REFL_CODE/Files
+    hires_figs : bool
+        whether you want eps instead of png files created
 
     """
 
@@ -502,19 +519,19 @@ def convert_phase(station, year, year_end=None, plt2screen=True,fr=20,tmin=0.05,
     json_data = station_file.read_file()
 
     if json_data['lat'] >= 0:
-        print('northern hemisphere summer')
+        print('Northern hemisphere summer')
         southern = False
     elif json_data['lat'] < 0:
-        print('southern hemisphere summer')
+        print('Southern hemisphere summer')
         southern = True
 
     else:
-        print(f"the required json file created from the make_json step could not be found: {station_file.get_file_path()}")
+        print(f"the required json file created by gnssir_input could not be found: {station_file.get_file_path()}")
         sys.exit()
 
     # for PBO H2O this was set using STATSGO. 5% is reasonable as a starting point for australia
     #tmin = 0.05  # for now
-    print('minimum texture value', tmin)
+    #print('minimum texture value', tmin)
     residval = 2  # for now
 
     # daily average file of phase results
@@ -525,11 +542,12 @@ def convert_phase(station, year, year_end=None, plt2screen=True,fr=20,tmin=0.05,
 
 
     # begging for a function ...
-    # overriding KE for now
+    # overriding Kelly's code for now
     if (fr == 1):
         fileout = myxdir + '/Files/' + subdir + '/' + station + '_phase_L1.txt'
     else:
         fileout = myxdir + '/Files/' + subdir + '/' + station + '_phase.txt'
+    print(subdir)
 
     if os.path.exists(fileout):
         avg_phase_results = np.loadtxt(fileout, comments='%')
@@ -685,12 +703,19 @@ def convert_phase(station, year, year_end=None, plt2screen=True,fr=20,tmin=0.05,
 
     outdir = f'{xdir}/Files/{subdir}'
 
-    plot_path = f'{outdir}/{station}_phase_vwc_result.png'
+    if hires_figs:
+        plot_path = f'{outdir}/{station}_phase_vwc_result.eps'
+    else:
+        plot_path = f'{outdir}/{station}_phase_vwc_result.png'
     print(f"Saving to {plot_path}")
     plt.savefig(plot_path)
 
 
-    plot_path = f'{outdir}/{station}_vol_soil_moisture.png'
+    if hires_figs:
+        plot_path = f'{outdir}/{station}_vol_soil_moisture.eps'
+    else:
+        plot_path = f'{outdir}/{station}_vol_soil_moisture.png'
+
     vwc_plot(station,t_datetime, nv, plot_path,circles) 
 
     if plt2screen:
@@ -702,9 +727,9 @@ def convert_phase(station, year, year_end=None, plt2screen=True,fr=20,tmin=0.05,
     print('>>> VWC results being written to ', vwcfile)
     with open(vwcfile, 'w') as w:
         N = len(nv)
-        w.write("% Soil Moisture Results for GPS Station {0:4s} \n".format(station))
+        w.write("% Soil Moisture Results for GNSS Station {0:4s} \n".format(station))
         w.write("% {0:s} \n".format('https://github.com/kristinemlarson/gnssrefl'))
-        w.write("% FracYr Year  DOY  VWC Month Day \n")
+        w.write("% FracYr    Year   DOY   VWC Month Day \n")
         for iw in range(0, N):
             whydoys = np.round(365.25 * (t[iw] - years))
 
@@ -776,7 +801,9 @@ def write_avg_phase(station, phase, fr,year,year_end,minvalperday,vxyz,subdir):
 
     print('Daily averaged phases will be written to : ', fileout)
     with open(fileout, 'w') as fout:
-        fout.write("% Year DOY Ph Phsig NormA MM DD \n")
+        # Year DOY Ph Phsig NormA MM DD
+          #            2012   1  10.00   2.60  0.962  0.00    1  1
+        fout.write("% Year DOY   Ph    Phsig NormA  empty  Mon Day \n")
         for requested_year in range(year, year_end + 1):
             for doy in range(1, 367):
             # put in amplitude criteria to keep out bad L2P results
@@ -824,42 +851,76 @@ def apriori_file_exist(station,fr):
     
     return os.path.exists(apriori_path_f) 
 
-def filter_out_snow(station, year1, year2, fr,snowmask):
+def load_phase_filter_out_snow(station, year1, year2, fr,snowmask):
     """
-    attempt to remove outliers from snow. only called if the snow filter file exists
+    Load all phase data and attempt to remove outliers from snow if snowmask provided. 
 
     Parameters
     ----------
     station : str
         four character station name
 
-    year1 : integer
+    year1 : int
         starting year
-    year2 : integer
+    year2 : int
         ending year
-    fr : integer
+    fr : int
         frequency, i.e. 1 or 20
     snowmask : str
         name/location of the snow mask file
+        None if this value is not going to be used
+
+    Returns
+    -------
+    dataexist : bool
+        whether phase data were found
+    year : numpy array of int
+        calendar years
+    doy : numpy array of int
+        day of year
+    hr : numpy array of floats
+        UTC hour of measurement
+    ph : numpy array of floats
+        LS phase estimates
+    azdata : numpy array of floats
+        average azimuth, degrees
+    ssat  : numpy array of int
+        satellite number
+    rh : numpy array of floats
+        reflector height, meters
+    amp_lsp : numpy array of floats
+        lomb scargle periodogram amplitude
+    amp_ls : numpy array of floats
+        least squares amplitude
+    ap_rh : numpy array of floats
+        apriori rh
+    results_trans : numpy array
+        all phase results concatenated into numpy array
+        plus column for quadrant and unwrapped phase
 
     """
-    xdir = os.environ['REFL_CODE']
-    found_override = False
-    if os.path.exists(snowmask):
-        print('found snow file')
-        override = np.loadtxt(snowmask, comments='%')
-        found_override = True
-
 #   now load the phase data
     newresults = []
     results_trans = []
-    #vquad = np.vstack((vquad, newl))
     vquad = np.empty(shape=[0, 16])
+    xdir = os.environ['REFL_CODE']
+    # output will go to 
+    fname = xdir + '/Files/' + station + '/raw.phase'  
 
-    if found_override:
-        dataexist, year, doy, hr, ph, azdata, ssat, rh, amp,results = load_sat_phase(station, year1,year2, fr)
-        # results were originally transposed - so untransposing them 
-        results = results.T
+    dataexist, results = load_sat_phase(station, year1,year2, fr)
+    results = results.T # backwards for consistency
+    if snowmask == None:
+        nr,nc = np.shape(results)
+        if nr > 0:
+            print('Number of rows and columns ', nr,nc)
+            raw = write_out_raw_phase(results,fname)
+    else:
+        print('Snow mask should exist')
+        override = np.loadtxt(snowmask, comments='%')
+        # adding nonsense because it doesn't like having only one value
+        #  which is a kluge i know
+        blah = np.array([[1, 2], [3, 4]])
+        override = np.vstack((override, blah))
         for year in range(year1,year2+1):
             ii = (results[:,0] == year) & (results[:,12] == fr)
         # it is easier for me to do this year by year
@@ -878,35 +939,58 @@ def filter_out_snow(station, year1, year2, fr,snowmask):
             newresults = np.append(newresults, masked_results)
             #vquad = np.vstack((vquad, thisyear_results[mask] ) )
             vquad = np.append(vquad, masked_results,axis=0)
+    #  
+        nr,nc = np.shape(vquad)
+        if nr > 0:
+            print('Number of rows and columns after snow filter ', nr,nc)
+            raw = write_out_raw_phase(vquad,fname)
 
-    # change to numpy?
-    nr,nc = np.shape(vquad)
-    print('Number of rows and columns now ', nr,nc)
+    rtrans= np.transpose(raw)
 
-    # 
-    results_trans= np.transpose(vquad)
-
-    print(np.shape(results_trans))
-
-    if len(results_trans) == 0:
-        print('no data ')
+    if len(rtrans) == 0:
+        print('no results ')
         dataexist = False
         year = []; doy = []; hr = []; ph = []; azdata = []; ssat = []
-        rh = []; amp = []
+        rh = []; amp_lsp = []; amp_ls=[]; ap_rh = []
     else:
         dataexist = True
         # save with new variable names
-        year = results_trans[0]
-        doy = results_trans[1]
-        hr = results_trans[2]
-        ph = results_trans[3]
-        azdata = results_trans[5]
-        ssat = results_trans[6]
-        rh = results_trans[13]
-        amp = results_trans[15]
+        year = rtrans[0]
+        doy = rtrans[1]
+        hr = rtrans[2]
+        ph = rtrans[3]
+        azdata = rtrans[5]
+        ssat = rtrans[6]
+        amp_ls = rtrans[7]
+        ap_rh = rtrans[11]
+        rh = rtrans[13]
+        amp_lsp = rtrans[15]
 
-# use same return command as in the original function
-    return dataexist, year, doy, hr, ph, azdata, ssat, rh, amp, results_trans
+    return dataexist, year, doy, hr, ph, azdata, ssat, rh, amp_lsp, amp_ls, ap_rh, rtrans
+
+
+def help_debug(rt,xdir, station):
+    """
+    Takes the input of phase files, read by other functions, and writes out a 
+    file to help with debugging  (comparion of matlab and python codes)
+
+    rt : numpy array of floats
+        contents of the phase files stored in a numpy array 
+    xdir : str
+        where the otuput should be written
+    station : str
+        name of the station
+
+    """
+    fname = xdir + '/Files/' + station +'/tmp.' + station
+    # don't have a priori rh values at this point
+    rhtrack = 0
+    #if True:
+        # open the file
+        #debug = write_all_phase(rt,fname,None,1,rhtrack)
+        # write to the file
+    #    debug = write_all_phase(rt,fname,debug,2,rhtrack)
+    #    debug.close()
 
 
 def load_avg_phase(station,fr):
@@ -919,14 +1003,17 @@ def load_avg_phase(station,fr):
     ----------
     station : str
         4 character station ID, lowercase
+    fr : int
+        frequency
 
     Returns
     -------
-    avg_exist : boolean
-
-    avg_date : ??
-
-    avg_phase : ??
+    avg_exist : bool
+        whether the necessary file exists
+    avg_date : list of floats
+        fractional year, i.e. year + doy/365.25
+    avg_phase : list of floats
+        average phase for a given day
 
     """
 
@@ -950,13 +1037,16 @@ def load_avg_phase(station,fr):
             avg_phase = phase
             avg_exist = True
 
+    if not avg_exist:
+        print('WARNING The average phase file used from a previous run for QC does not exist as yet')
+
     return avg_exist, avg_date, avg_phase
 
 
 def load_sat_phase(station, year, year_end, freq):
     """
-    Picks up the phase data from local results section
-    return to main code whether dataexist, and np arrays of year, doy, hr, phase, azdata, ssat
+    Picks up the phase estimates from local (REFL_CODE) results section
+    and returns most of the information from those files
 
     Parameters
     ----------
@@ -973,29 +1063,13 @@ def load_sat_phase(station, year, year_end, freq):
     -------
     dataexist : bool
         whether data found?
-    year : numpy array of int
-        full years
-    doy : numpy array of int
-        days of year
-    hr : float
-        fractional day (UTC)
-    ph : float
-        phases (deg)
-    azdata : float
-        azimuths (deg)
-    ssat : int
-        satellites (deg)
-    rh : float
-        reflector height (m)
-    amp : float
-        amplitudes of peak LSP 
-
-    results : ??
+    results : numpy array of floats
+        basically one variable with everything in the original columns from the daily phase files
 
     """
     print('Requested frequency: ', freq)
     dataexist = False
-
+    xdir = os.environ['REFL_CODE']
     xfile = xdir + '/input/override/' + station + '_vwc' 
     found_override = False
     # not implementing this yet
@@ -1010,9 +1084,10 @@ def load_sat_phase(station, year, year_end, freq):
         year_end = year
 
     results = []
-    for year in np.arange(year, year_end+1):
+    for yyyy in range(year, year_end+1):
+        print('reading in year', yyyy)
         # where the results are stored
-        data_dir = thedir / str(year) / 'phase' / station
+        data_dir = thedir / str(yyyy) / 'phase' / station
         local_results = read_files_in_dir(data_dir)
         if local_results:
             results.extend(local_results)
@@ -1027,28 +1102,444 @@ def load_sat_phase(station, year, year_end, freq):
     results = results[ii, :]
     print('Total phase measurements for this frequency: ', len(results))
 #    common_elements, ar1_i, ar2_i = np.intersect1d(ar1, ar2, return_indices=True)
-    minyear = np.min(np.unique(results[:,0]))
-    maxyear = np.max(np.unique(results[:,0]))
-    #print(minyear,maxyear)
+    #minyear = np.min(np.unique(results[:,0]))
+    #maxyear = np.max(np.unique(results[:,0]))
     nr,nc = np.shape(results)
     print(nr, ' number of rows')
 
     results = results.T  # dumb, but i was using this convention.  easier to maintain
 
-    if len(results) == 0:
-        print('no data at that frequency')
-        year = []; doy = []; hr = []; ph = []; azdata = []; ssat = []
-        rh = []; amp = []
+    if len(results) > 0:
+        dataexist = True 
+
+    return dataexist, results
+
+
+def set_parameters(station, minvalperday,tmin,tmax,min_req_pts_track,fr, year, year_end,subdir,plt,auto_removal,warning_value):
+    """
+
+    Parameters
+    ----------
+    station : str
+        4 character station name
+
+    Returns
+    -------
+    minvalperday : int
+        number of phase values required each day
+    tmin : float
+        min soil texture
+    tmax : float
+        max soil texture
+    min_req_pts_track: int 
+        minimum number of phase values per year per track
+    freq : int
+        frequency to use (1,20 allowed)
+    year_end : int
+        last year to analyze
+    subdir : str
+        name for subdirectory used in subdirectory of REFL_CODE/Files
+    plt : bool
+        whether you want plots to come to the screen
+    auto_removal : bool
+        whther tracks should be removed when they fail QC
+    warning_value : float
+        phase RMS needed to trigger warning
+    plot_legend : bool
+        whether to plot PRN numbers on the phase & amplitude results
+
+    """
+    # originally this was for command line interface ... 
+    remove_bad_tracks = auto_removal # ??
+    plot_legend = True # default is to use them
+    circles = False
+
+    g.checkFiles(station, '')
+
+    # not using extension
+    lsp = gnssir.read_json_file(station, '')
+    # pick up values in json, if available
+    if 'vwc_min_soil_texture' in lsp:
+        tmin = lsp['vwc_min_soil_texture']
+    if 'vwc_max_soil_texture' in lsp:
+        tmax = lsp['vwc_max_soil_texture']
+    if 'vwc_minvalperday' in lsp:
+        minvalperday = lsp['vwc_minvalperday']
+    if 'vwc_warning_value' in lsp:
+        warning_value = lsp['vwc_warning_value']
+    if 'vwc_min_req_pts_track' in lsp:
+        min_req_pts_track = lsp['vwc_min_req_pts_track']
+    if 'vwc_plot_legend' in lsp:
+        plot_legend = lsp['vwc_plot_legend']
+    if 'vwc_circles' in lsp:
+        circles = lsp['vwc_circles']
+    if 'vwc_min_norm_amp' in lsp:
+        min_norm_amp = lsp['vwc_min_norm_amp']
     else:
-        dataexist = True
-        # save with new variable names 
-        year = results[0]
-        doy = results[1]
-        hr = results[2]
-        ph = results[3]
-        azdata = results[5]
-        ssat = results[6]
-        rh = results[13]
-        amp = results[15]
+        min_norm_amp = 0.5  # trying this out
+
+    if (len(station) != 4):
+        print('station name must be four characters')
+        sys.exit()
+
+    if (len(str(year)) != 4):
+        print('Year must be four characters')
+        sys.exit()
+
+    freq = fr # KE kept the other variable
+
+    if not year_end:
+        year_end = year 
+
+    # originally was making people input these on the command line
+    # now first try to read from json.  if not there they will be set here
+
+    if tmin is None:
+        tmin = 0.05
+
+    if tmax is None:
+        tmax = 0.5
+
+    # default is station name
+    if subdir == None:
+        subdir = station 
+
+    # make sure subdirectory exists
+    g.set_subdir(subdir)
+
+    if not plt:
+        print('no plots will come to screen. Will only be saved.')
+
+    print('minvalperday/tmin/tmax/min_req_tracks', minvalperday, tmin, tmax, min_req_pts_track)
+
+    return minvalperday, tmin, tmax, min_req_pts_track, freq, year_end, subdir, \
+            plt, remove_bad_tracks, warning_value, min_norm_amp, plot_legend,circles
+
+def write_all_phase(v,fname):
+    """
+    writes out preliminary phase values and other metrics for advanced vegetation
+    option.  This is in the hope that it can be used in clara chew's
+    dissertation algorithm.
+
+    File is written to $REFL_CODE/Files/station/station_all_phase.txt I think
+
+    Parameters
+    ----------
+    v : numpy of floats as defined in vwc_cl
+        TBD
+        year, doy, phase, azimuth, satellite number
+        estimated RH, LSP amplitude, LS amplitude, UTC hours
+        raw LSP amp, raw LS amp
+    fname : str
+        name of the output file
+    filestatus : int
+        1, open the file
+        2, write to file (well, really any value)
+    rhtrack: float
+        apriori reflector height for the given track, meters
+
+    Returns
+    -------
+    allrh : fileID
+
+    """
+
+    #if filestatus == 1:
+    if True:
+        print('Writing interim phase values to ', fname)
+        header1=  'Year DOY Hour   Phase   Nv  Azimuth  Sat  Ampl emin emax  DelT aprioriRH  freq estRH  pk2noise LSPAmp'
+        header2 = '(1)  (2)  (3)    (4)   (5)    (6)    (7)  (8)  (9)  (10)  (11)   (12)     (13)  (14)    (15)    (16)'
+
+        #allrh.write(" {0:s}  \n".format(header1))
+        #allrh.write(" {0:s}  \n".format(header2))
+
+        #return allrh
+
+    nr,nc = v.shape
+    # sort by time
+    ii = np.argsort(v[:,0] + v[:,1]/365.25)
+    v = v[ii,:]
+
+    with open(fname, 'w') as my_file:
+        np.savetxt(my_file, [], header=header1, comments='%')
+        #np.savetxt(my_file, [], header=header2, comments='%')
+    #result = [[year, doy, utctime, phase, nv, avg_azim, sat_number, amp, min_el, max_el, del_t, rh_apriori, freq, max_f, obs_pk2noise, max_amp]]
+    #np.savetxt(my_file, result, fmt="%4.0f %3.0f %6.2f %8.3f %5.0f %6.1f %3.0f %5.2f %5.2f %5.2f %6.2f %5.3f %2.0f %6.3f %6.2f %6.2f", comments="%")
+
+
+    #for i in range(0,nr):
+    #    q = old_quad(v[i,3])
+    #    a = v[i,5] ; sat = v[i,6]; amp_lsp = v[i,15]
+    #    amp_ls = v[i,7] ; rh = v[i,13]
+    #    allrh.write(" {0:4.0f} {1:3.0f} {2:7.3f} {3:7.1f} {4:2.0f} {5:7.3f} {6:7.3f} {7:7.3f} {8:2.0f} \
+    #            {9:7.2f} {10:7.2f} {11:7.2f} {12:7.3f}\n".format(v[i,0], v[i,1], v[i,3],a, sat,rh,amp_lsp,amp_ls,\
+    #            q, v[i,2],v[i,10], rhtrack ))
+
+
+def old_quad(azim):
+    """
+    calculates oldstyle quadrants from PBO H2O
+
+    Parameters
+    ----------
+    azim : float
+        azimuth, dgrees
+    q : int
+        old quadrant system used in pboh2o
+    """
+    q = 1
+    if azim < 90:
+        q= 1
+    elif (azim >= 90) and (azim < 180):
+        q = 4 
+    elif (azim >= 180) and (azim < 270):
+        q = 3
+    elif (azim >= 270) and (azim <= 360):
+        q =2
+
+    return q
+
+
+def kinda_qc(satellite, rhtrack,meanaztrack,nvalstrack, amin,amax, y, t, new_phase, 
+             avg_date,avg_phase,warning_value,ftmp,remove_bad_tracks,k4,avg_exist):
+    """
+    Parameters
+    ----------
+    satellite : int
+        satellite number
+    rhtrack: float
+        a priori reflector height 
+    meanaztrack : float
+        I think it is the azimuth of the track, degrees
+    nvalstrack : int
+        not sure?
+    amin : int
+        min az of this quadrant
+    amax : int
+        max az of this quadrant
+    y : numpy array of ints
+        year
+    t : numpy array of ints
+        day of year
+    new_phase : numpy array of floats
+        phase values for a given satellite track ??
+    avg_date : numpy array of floats
+        y + doy/365.25 I think
+    avg_phase : numpy array of floats
+        average phase, in degrees
+    warning_value : float
+        phase noise value
+    ftmp : file ID 
+        for writing
+    remove_bad_tracks : bool
+        whether you write out new tracks with bad ones removed
+    k4 : int
+        number of tracks?
+    avg_exist : bool
+        whether you have previous solution to compare to
+    
+        
+    """
+    # this is a kind of quality control -use previous solution to have 
+    # better feel for whether current solution works. defintely needs to go in a function
+    if avg_exist:
+        # quadrant results for this satellite track
+        satdate = y + t/365.25
+        satphase = new_phase
+        keepit=False
+
+        # figure out intersection with "good" results
+        inter, id1, id2 = np.intersect1d(avg_date, satdate, assume_unique=True, return_indices=True)
+        aa = avg_phase[id1]
+        bb = satphase[id2]
+        if len(aa) > 0:
+            res = np.round(np.std(aa - bb), 2)
+            addit = ''
+            keepit = True
+            if (res > warning_value ) :
+                addit = '>>>>>  Consider Removing This Track <<<<<'
+                if remove_bad_tracks:
+                    addit = '>>>>>  Removing This Track - rerun to see effect <<<<<'
+                    keepit = False
+            if keepit:
+                ftmp.write("{0:3.0f} {1:7.2f} {2:3.0f} {3:7.1f} {4:7.0f} {5:4.0f} {6:4.0f} \n".format(k4,rhtrack, 
+                       satellite,meanaztrack,nvalstrack,amin,amax))
+                k4 = k4 + 1
+                print(f"Npts {len(aa):4.0f} SatNu {satellite:2.0f} Residual {res:6.2f} Azims {amin:3.0f} {amax:3.0f} {addit:20s} ")
+
+    else:
+        print('You do not have a previous solution to compare to so I cannot compute QC stats. Rerun vwc')
+
+    return k4
+
+def save_vwc_plot(fig, pngfile):
+    """
+    Parameters
+    ----------
+    fig : matplotlib figure
+        the figure definition you define when you open a figure
+    pngfile : str
+        name of the png file to be saved
+    """
+    fig.savefig(pngfile,format="png")
+    print('Saving to ', pngfile)
+
+    return
+
+def rename_vals(year_sat_phase, doy, hr, phase, azdata, ssat, amp_lsp, amp_ls, rh, ap_rh,ii):
+    """
+    this is just trying to clean up vwc.py  
+    send indices ii - and return renamed variables.  
+
+    Parameters
+    ----------
+    year_sat_sat
+    doy : 
+    hr : 
+    phase : 
+    azdata : 
+    ssat : 
+    amp_lsp : 
+    amp_ls
+    rh : 
+    ap_rh :
+    ii :
+
+    Returns
+    -------
+    y : numpy array of int
+        year
+    t : numpy array of int
+        day of year 
+    h : numpy array of floats
+        hour of the day (UTC)
+    x : numpy array of floats
+        phase, degrees
+    azd: numpy array of floats
+        azimuth for the track
+    s : numpy array of int
+    amps_lsp : numpy array of floats
+        LSP amplitude
+    amps_ls : numpy array of floats
+        least squares amplitude
+    rhs : numpy array of floats
+        estimated RH (m)
+    ap_rhs : numpy array of floats
+        a priori RH (m)
+
+    """
+    y = year_sat_phase[ii]
+    t = doy[ii]
+    h = hr[ii] # this is fractional hour of the day, GPS time 
+    x = phase[ii]
+    # should be so we could do subdaily VWC
+    azd = azdata[ii] # azimuth, in degrees
+    s = ssat[ii] # array of satellites numbers
+    amps_lsp = amp_lsp[ii] # this amplitude is RH amplitude 
+    amps_ls = amp_ls[ii] # this amplitude is phase amplitude 
+    rhs = rh[ii] # estimated RH
+    ap_rhs = ap_rh[ii] # apriori RH
+
+    return y,t,h,x,azd,s,amps_lsp,amps_ls,rhs, ap_rhs
+
+
+def write_out_raw_phase(v,fname):
+    """
+    write daily phase values used in vwc to a new consolidated file
+    I added columns for quadrant and unwrapped phase
+
+    Parameters
+    ----------
+    v : numpy array
+        phase results read for multiple years. 
+        could be with snow filter applied
+    fname : str
+        filename for output
+
+    Returns
+    -------
+    newv : numpy array
+        original variable v with columns added for
+        quadrant (1-4) and unwrapped phase 
+
+    """
+
+    print('Writing to ', fname)
+    # make sure v is numpy 
+    v = np.asarray(v)
+    nr,nc = v.shape; 
+# sort by time
+    ii = np.argsort(v[:,0] + v[:,1]/365.25)
+    v = v[ii,:]
+# calculate quadrants cause it makes life easier
+    q = np.zeros((nr,1)) #
+    for i in range(nr):
+        q[i] = old_quad(v[i,5])
+
+    # make a column full of zeros to store unwrapped phase
+    unwrapped = np.zeros((nr,1)) #
+
+    # add quadrant column
+    newv = np.hstack((v,q))
+    # add unwrapped column
+    newv = np.hstack((newv,unwrapped))
+
+    # get a list of possible satellites
+    sat_list = np.unique(v[:,6])
+    # discontinuity used in phase wrapping
+    discont = 270
+
+    # make a variable to return
+    tnewv = np.zeros((nr,18)) #
+    for ql in [1,2,3,4]:
+        for s in sat_list:
+            iw = (newv[:,16] == ql) & (newv[:,6] == s)
+            tnewv = newv[iw,:]
+            if (len(tnewv) > 0):
+                doy = tnewv[:,1]; phase = tnewv[:,3]
+                unwrap_phase = np.unwrap(phase,period=360,discont=discont)
+                newv[iw,17] = unwrap_phase
+
+    # headers for output file
+    h1 = "Year DOY Hour   Phase   Nv  Azim   Sat  Ampl emin emax   DelT aprRH  fr  estRH  pk2n  LSPAmp  quad  unphase\n"   
+    h2 = "(1)  (2)  (3)    (4)   (5)   (6)   (7)  (8)  (9)  (10)  (11)   (12)  (13)  (14)   (15)   (16)  (17)  (18) "
+
+    with open(fname, 'w') as my_file:
+        np.savetxt(my_file, newv, fmt="%4.0f %3.0f %6.2f %8.3f %5.0f %6.1f %3.0f %5.2f %5.2f %5.2f %6.2f %5.3f %2.0f %6.3f %6.2f %6.2f %2.0f %8.3f ",header=h1+h2,comments='%')
+
+    return newv
+
+def write_phase_for_advanced(filename, vxyz):
+    """
+    Writes out a file of interim phase results for advanced models
+    developed by Clara Chew
+
+    File generally written to $REFL_CODE/Files/<station>/all_phase.txt
+
+    Parameters
+    ----------
+    filename : str
+        name for output file
+    vxyz : numpy array of floats
+        as defined in vwc_cl.py
+    """
+    # do a quick sort as they are likely quadrant sorted now
+    ii = np.argsort(vxyz[:,0] + vxyz[:,1]/365.25)
+    vxyz = vxyz[ii,:]
+    #headers for output file - these are not correct BTW
+    print('writing interim file for advanced model ', filename)
+    h1 = "Year DOY Phase  Azim Sat    RH    nLSPA nLSA    Hour   LSPA   LS  apRH  quad  delRH  vegM\n"
+    h2 = "(1)  (2)  (3)   (4)  (5)    (6)    (7)   (8)     (9)   (10)  (11)  (12)  (13)  (14)  (15) "
+    #2012   1   9.19  315.6  1   1.850   0.97   0.98  0.59 19.80 19.79  1.85  2
+    with open(filename, 'w') as my_file:
+        np.savetxt(my_file, vxyz, fmt="%4.0f %3.0f %6.2f %6.1f %2.0f %7.3f %6.2f %6.2f %5.2f %6.2f %6.2f %6.3f %2.0f %6.3f %2.0f  ",header=h1+h2,comments='%')
+
+    return
+#                   if adhoc_snow:
+#                        ii = (norm_ampLSP > 0.5)
+#                        y,t,h,new_phase,azd,s,amp_lsps,amp_lss,rhs,ap_rhs = \
+#                                qp.rename_vals(y, t, h, new_phase, azd, s, amp_lsps, amp_lss, rhs, ap_rhs,ii)
+#                        norm_ampLSP = norm_ampLSP[ii]
+#                        norm_ampLS = norm_ampLS[ii]
+#                        fracyear = fracyear[ii]
 
-    return dataexist, year, doy, hr, ph, azdata, ssat, rh, amp, results
