@@ -1,13 +1,5 @@
 # -*- coding: utf-8 -*-
-"""
-author: kristine larson
-prn to gps conversion script
-gps number also known as SVN
 
-some of these functions are no longer called.
-
-
-"""
 import argparse
 import numpy as np
 import time
@@ -22,11 +14,12 @@ import gnssrefl.gps as g
 
 def download_prn_gps():
     """
-    try to download a file from JPL ... 
+    downloads PRN to GPS name conversion file from JPL
+
     """
     url='https://sideshow.jpl.nasa.gov/pub/gipsy_products/gipsy_params/PRN_GPS.gz'
     file_name='PRN_GPS.gz'
-    print('Downloading the file from JPL')
+    print('# Downloading the file from JPL')
   
     try:
         urllib.request.urlretrieve(url, file_name)
@@ -36,34 +29,18 @@ def download_prn_gps():
 
     return
 
-
-def write_jpl_pickle_file(pname,tv):
-    """
-    write out PRN_GPS info
-    """
-    f = open(pname, 'wb')
-    pickle.dump(tv, f)
-    f.close()
-
-
-def read_jpl_pickle_file(pname):
-    """
-    read in PRN_GPS info
-    """
-    tv=[]
-    if os.path.isfile(pname):
-        print('read existing pickle file')
-        f = open(pname, 'rb')
-        tv = pickle.load(f)
-        f.close()
-        print(tv)
-
-    return tv
-
-
 def read_jpl_file(fname):
     """
-    send filename with prn gps conversion info
+    Parameters
+    ----------
+    fname : str
+        filename with prn gps conversion info
+
+    Returns
+    -------
+    tv : list
+        start date (frac year), end date, GPS#, PRN #
+
     """
     tv = [] # in case there is some problem
     #fname = 'PRN_GPS'
@@ -90,18 +67,29 @@ def read_jpl_file(fname):
 
 
 def main():
+    """
+    Displays the PRN and SVN numbers for the GPS
+    constellation on a given date.
 
+    Parameters
+    ----------
+    date : str
+        example 2012-01-01
+    overwrite : bool, optional
+        whether you want to download new file from JPL
+
+    """
 
     parser = argparse.ArgumentParser()
     parser.add_argument("date", help="2012-12-05", type=str)
-    parser.add_argument("-overwrite", help="set to T to download the existing PRN_GPS file", type=str)
+    parser.add_argument("-overwrite", help="set to T or True to download new PRN_GPS file", type=str)
     args = parser.parse_args()
     cdate = args.date
     seekTime =  g.cdate2nums(cdate)
     found = False
     fout = 'PRN_GPS'
     xdir = os.environ['REFL_CODE']
-    if args.overwrite == 'T':
+    if (args.overwrite == 'T') or (args.overwrite == 'True'):
         print('# Will remove existing file, if it exists locally, and will download a new one')
         subprocess.call(['rm','-f','PRN_GPS'])
         download_prn_gps()
@@ -129,39 +117,23 @@ def main():
         print('No input file, no output')
         sys.exit()
 
-    #time1 = time.time()
-    #picklename = 'PRN_GPS.pickle'
-    #x = read_jpl_pickle_file(picklename)
-    #time2 = time.time()
-    #print(time2-time1, 'reading pickle')
 
-    #time1 = time.time()
     x = read_jpl_file(fout)
 
-    #x returns date1, date2, GPS, and PRN
-    #time2 = time.time()
-    #print(time2-time1, 'reading txt')
 
     #N,nc = x.shape
     # check all 32 PRN numbers
+
+    xx = 0
     for rprn in range(1,33):
         xxx = x[ (rprn == x[:,3] ) & (seekTime >= x[:,0]) & (seekTime <= x[:,1] ), 2 ] 
         gps_name = xxx.astype(int)
         if gps_name > 0:
+            xx = xx + 1
             print("%2.0f  %2.0f " % (rprn, gps_name[0]) )
-            #print(rprn,gps_name[0])
-
+    print('\n There were ', xx, ' valid GPS satellites on ', cdate)
 
 
 if __name__ == "__main__":
     main()
 
-    #for rprn in range(1,33):
-    #    for i in range(0,N):
-    #        t1 = x[i,0]
-    #        t2 = x[i,1]
-    #        prn = x[i,3]
-    #        gps = x[i,2]
-    #        if (prn == rprn) and ((seekTime >= t1) and (seekTime < t2)):
-    #            #print(prn,gps)
-    #            break
