@@ -1,7 +1,5 @@
-"""
-called by quickLook_cl.py
-quickLook functions 
-"""
+# I do not think this is used anymore
+# 
 import sys
 import os
 import numpy as np
@@ -17,7 +15,8 @@ import gnssrefl.gps as g
 import gnssrefl.rinex2snr as rinex
 
 
-def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pele,satsel,PkNoise,fortran,pltscreen,azim1,azim2,ediff,**kwargs):
+def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pele,satsel,PkNoise,fortran,
+        pltscreen,azim1,azim2,ediff, delTmax, hires_figs,**kwargs):
     """
     This is the main function to compute spectral characteristics of a SNR file.
     It takes in all user inputs and calculates reflector heights. It makes two png files to summarize
@@ -61,6 +60,10 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
          maximum azimuth in degrees
     ediff : float
          QC parameter - restricts length of arcs (degrees)
+    delTmax : float
+         maximum arc length in minutes
+    hires_figs : bool
+         whether to use eps instead of png
 
     """
 
@@ -104,7 +107,7 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
     # various defaults - ones the user doesn't change in this quick Look code
     # changed this december 4, 2022
     # changed it back on december 20, 2022
-    delTmax = 75 # this is how long an arc can be in minutes
+    #delTmax = 75 # this is how long an arc can be in minutes
     polyV = 4 # polynomial order for the direct signal
     desiredP = 0.01 # 1 cm precision for a "quick Look"
 
@@ -129,10 +132,8 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
     else:
         if True:
             obsfile, obsfileCmp, snre =  g.define_and_xz_snr(station,year,doy,snr_type)
-            if snre:
-                dkfjaklj = True
-            else:
-                print('>>>> The SNR the file needs does not exist ',obsfile)
+            if not snre:
+                print('>>>> The SNR file this code needs does not exist ',obsfile)
                 print('Please use rinex2snr to make a SNR file')
                 sys.exit()
     allGood,sat,ele,azi,t,edot,s1,s2,s5,s6,s7,s8,snrE = read_snr_simple(obsfile)
@@ -191,11 +192,7 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
 
             # this means no satellite list was given, so get them all
             if satsel == None:
-                #satlist = g.find_satlist(f,snrE)
-                #march 29, 2021 made l2c and l5 time dependent
                 satlist = g.find_satlist_wdate(f,snrE,year,doy)
-                #print(f,year,doy)
-                #print(satlist)
             else:
                 satlist = [satsel]
 
@@ -306,11 +303,14 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
         plt.suptitle(tt, fontsize=FS)
             # if you have no results, no point plotting them!
         if (allpoints > 0):
-            filename = fdir + '/quickLook_lsp.png'
-            print('plot saved to ', filename)
+            if hires_figs:
+                filename = fdir + '/quickLook_lsp.eps'
+            else:
+                filename = fdir + '/quickLook_lsp.png'
+            print('Plot saved to ', filename)
             plt.savefig(filename)
         # make second plot
-            goodbad(quicklog,station,year,doy,minH,maxH,PkNoise,reqAmp,f,e1,e2)
+            goodbad(quicklog,station,year,doy,minH,maxH,PkNoise,reqAmp,f,e1,e2,hires_figs)
         else:
             print('You made a selection that does not exist (i.e. frequency or satellite or constellation)')
 
@@ -325,7 +325,7 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
 
     return data,datakey
 
-def goodbad(fname,station,year,doy,h1,h2,PkNoise,reqAmp,freq,e1,e2):
+def goodbad(fname,station,year,doy,h1,h2,PkNoise,reqAmp,freq,e1,e2,hires_figs):
     """
     makes a plot that shows "good" and "bad" refletor height retrievals as a 
     function of azimuth
@@ -354,6 +354,8 @@ def goodbad(fname,station,year,doy,h1,h2,PkNoise,reqAmp,freq,e1,e2):
         minimum elevation angle (deg)
     e2 : float
         maximum elevation angle (deg)
+    hires_figs: bool
+        whether you want eps instead of png
 
     Returns
     -------
@@ -422,8 +424,12 @@ def goodbad(fname,station,year,doy,h1,h2,PkNoise,reqAmp,freq,e1,e2):
 
     # existence of the output directory is checked earlier
     fdir = os.environ['REFL_CODE'] + '/Files/' + station 
-    f = fdir + '/quickLook_summary.png'
-    print('plot saved to ', f)
+    if hires_figs :
+        f = fdir + '/quickLook_summary.eps'
+    else:
+        f = fdir + '/quickLook_summary.png'
+
+    print('Plot saved to ', f)
     plt.savefig(f)
 
 def read_snr_simple(obsfile):
