@@ -16,16 +16,16 @@ def parse_arguments():
     parser.add_argument("-fr", default=None, help="frequency (use all if you want both 1 and 20)", type=str)
     parser.add_argument("-doy_end", "-doy_end", default=None, type=int, help="doy end")
     parser.add_argument("-year_end", "-year_end", default=None, type=int, help="year end")
-    parser.add_argument("-e1", default=None, type=int),
-    parser.add_argument("-e2", default=None, type=int),
-    parser.add_argument("-plot", default=None, type=str)
+    parser.add_argument("-e1", default=None, type=float),
+    parser.add_argument("-e2", default=None, type=float),
+    parser.add_argument("-plt", default=None, type=str, help="plots come to the screen - which you do not want!")
     parser.add_argument("-screenstats", default=None, type=str, help="stats come to the screen")
-    parser.add_argument("-gzip", default=None, type=str, help="gzip SNR files" )
+    parser.add_argument("-gzip", default=None, type=str, help="gzip SNR files after use, default is True" )
 
     args = parser.parse_args().__dict__
 
     # convert all expected boolean inputs from strings to booleans
-    boolean_args = ['plot', 'screenstats', 'gzip']
+    boolean_args = ['plt', 'screenstats', 'gzip']
     args = str2bool(args, boolean_args)
 
     # only return a dictionary of arguments that were added from the user - all other defaults will be set in code below
@@ -33,74 +33,58 @@ def parse_arguments():
 
 
 def quickphase(station: str, year: int, doy: int, year_end: int = None, doy_end: int = None, snr: int = 66, 
-        fr: str = '20', e1: int = 5, e2: int = 30, plot: bool = False, screenstats: bool = False, gzip:bool=False):
+        fr: str = '20', e1: float = 5, e2: float = 30, plt: bool = False, screenstats: bool = False, gzip: bool = True):
     """
-    quickphase computes phase for the given inputs (station, years, doy, elevation angles)
-    These phase results are subquently used in vwc. The command line call is phase
+    quickphase computes phase, which are subquently used in vwc. The command line call is phase
     (which maybe we should change).
     
-    Examples:
-   
-    For one day
-
+    Examples
+    --------
     phase p038 2021 4
-
-    For the whole year
+        analyzes data for year 2021 and day of year 4
 
     phase p038 2021 1 -doy_end 365 
-
+        analyzes data for the whole year
 
     Parameters
     ----------
     station: str
         4 character ID of the station.
-
     year: int
-        Year to evaluate.
-
-    doy: integer
+        full Year to evaluate.
+    doy: int
         day of year to evaluate.
-        Default is None.
-
-    year_end: integer, optional
+    year_end: int, optional
         year to end analysis. Using this option will create a range from year-year_end.
         Default is None.
-
-    doy_end: integer, optional
+    doy_end: int, optional
         Day of year to end analysis. Using this option will create a range of doy-doy_end.
         If also using year_end, then this will be the day to end analysis in the year_end requested.
         Default is None.
-
-    snr : integer, optional
+    snr : int, optional
         SNR format. This tells the code what elevation angles are in the SNR file
         value options:
+
             66 (default) : data with elevation angles less than 30 degrees
 
             99 : data with elevation angles between 5 and 30 degrees
 
-            88 : data with elevation angles between 5 and 90 degrees
+            88 : data with all elevation angles 
 
             50 : data with elevation angles less than 10 degrees
 
-    fr : string, optional
-        GNSS frequency. Currently only supports L2C.
-        Default is 20 (l2c)
-
-    e1 : integer, optional
-        Elevation angle lower limit in degrees for the LSP.
-        default is 5
-
-    e2: integer, optional
-        Elevation angle upper limit in degrees for the LSP.
-        default is 30
-
-    plot: boolean, optional
-        Whether to plot results.
-        Default is False
-
-    screenstats: boolean, optional
-        Whether to print stats to the screen.
-        Default is False
+    fr : str, optional
+        GNSS frequency. Currently only supports L2C. Default is 20 (l2c)
+    e1 : float, optional
+        Elevation angle lower limit in degrees for the LSP. default is 5
+    e2: float, optional
+        Elevation angle upper limit in degrees for the LSP. default is 30
+    plt: bool, optional
+        Whether to plot results. Default is False
+    screenstats: bool, optional
+        Whether to print stats to the screen. Default is False
+    gzip : bool, optional
+        gzip the SNR file after use.  Default is True
 
     Returns
     -------
@@ -112,6 +96,9 @@ def quickphase(station: str, year: int, doy: int, year_end: int = None, doy_end:
     """
 
     compute_lsp = True # used to be an optional input
+    if len(station) != 4:
+        print('Station name must be four characters long. Exiting.')
+        sys.exit()
 
     if fr == 'all':
         fr_list = [1, 20]
@@ -156,10 +143,10 @@ def quickphase(station: str, year: int, doy: int, year_end: int = None, doy_end:
 
             for d in date_range:
                 print('Analyzing year/day of year ' + str(y) + '/' + str(d))
-                qp.phase_tracks(station, y, d, snr, fr_list, e1, e2, pele, plot, screenstats, compute_lsp, gzip)
+                qp.phase_tracks(station, y, d, snr, fr_list, e1, e2, pele, plt, screenstats, compute_lsp, gzip)
     else:
         for d in np.arange(doy, doy_end + 1):
-            qp.phase_tracks(station, year, d, snr, fr_list, e1, e2, pele, plot, screenstats, compute_lsp, gzip)
+            qp.phase_tracks(station, year, d, snr, fr_list, e1, e2, pele, plt, screenstats, compute_lsp, gzip)
 
 
 def main():
