@@ -1,3 +1,4 @@
+from scipy.interpolate import interp1d
 import math
 import numpy as np
 import os
@@ -282,9 +283,8 @@ def calcAzEl_new(prn, newf,recv,u,East,North):
         etime = newf[t,1]
         r=np.subtract(satv,recv) # satellite minus receiver vector
         eleA = g.elev_angle(u, r)*180/np.pi
-        # change from 26 to 31 so at least 30 degrees is supported
-        #if ( (eleA >= 0) & (eleA <= 26)):
-        if ( (eleA >= 0) & (eleA <= 31)):
+        #Check if the elevation angle is within the allowed range
+        if ( (eleA >= 0) & (eleA <= 61)):
             azimA = g.azimuth_angle(r, East, North)
 #            print(etime, eleA, azimA)
             newl = [prn, eleA, azimA]
@@ -409,7 +409,9 @@ def make_FZ_kml(station, filename,freq, el_list, h, lat,lng,azlist):
         #pname = 'ElevAngle {0}'.format(int(el), prn)
         ls = kml.newpolygon(name=pname, altitudemode='relativeToGround') # creating new polygon for each azimuth zone in azlist
         ls.outerboundaryis = points
+        # wont work ...
         # print(points)
+        #ls.labelstyle.scale = 5
         if el ==el_list[0]:
             ls.style.linestyle.color = simplekml.Color.yellow
             ls.style.linestyle.width = 3
@@ -457,6 +459,7 @@ def make_FZ_kml(station, filename,freq, el_list, h, lat,lng,azlist):
 
     # try adding a point at the station
     pnt = kml.newpoint(name=station)
+    #pnt.labelstyle.scale = 3
     pnt.coords = [(lng, lat)]
     pnt.style.iconstyle.icon.href = 'http://maps.google.com/mapfiles/kml/shapes/placemark_circle.png'
 
@@ -472,6 +475,8 @@ def set_system(system):
     ----------
     system : str
         gps,glonass,beidou, or galileo
+    it : int
+        simple pointer from former code. 1 is GPS, 2 is Glonass etc
 
     Returns
     -------
@@ -479,6 +484,7 @@ def set_system(system):
         orbit filename with Cartesian coordinates for one day 
 
     """
+    it = 1
     xdir = os.environ['REFL_CODE'] 
     if not os.path.exists(xdir):
         print('REFL_CODE environment variable must be set. Exiting.')
@@ -490,18 +496,23 @@ def set_system(system):
     if (system is None) or (system == 'gps'):
         system = 'gps'
         orbfile = xdir + 'GPSorbits_21sep17.txt'
+        it = 1
     elif (system == 'galileo'):
         orbfile = xdir + 'GALILEOorbits_21sep17.txt'
+        it = 3
     elif (system == 'glonass'):
         orbfile = xdir + 'GLONASSorbits_21sep17.txt'
+        it = 2
     elif (system == 'beidou'):
         orbfile = xdir + 'BEIDOUorbits_21sep17.txt'
+        it = 4
     else:
        print('Using GPS')
        system = 'gps'
+       it = 1
        orbfile = xdir + 'GPSorbits_21sep17.txt'
 
-    return orbfile
+    return orbfile, it 
 
 def save_reflzone_orbits():
     """
@@ -532,8 +543,8 @@ def save_reflzone_orbits():
         if not os.path.exists(xdir + orbfile):
             print('download from github and put in local Files directory: ', otypes)
             wget.download(githubdir+orbfile, xdir + orbfile)
-        else:
-            print('file already exists', otypes)
+        #else:
+        #    print('file already exists', otypes)
 
     found = 0 
     for otypes in ['GPS','GLONASS','GALILEO','BEIDOU']:
@@ -546,3 +557,96 @@ def save_reflzone_orbits():
         foundfiles = True
 
     return foundfiles 
+
+def nyquist_simple(t,elev,azims, emin,emax,azriseset,reqsamplerate):
+    """
+    given numpy array of elevation angles (elev)
+    and limtis (emin,emax) and azriseset, reqsamplerate
+
+    Parameters
+    ----------
+    t : ??
+        cannot remember
+    elev : numpy array of floats
+        elevation angle of rising/setting arcs
+    azims : numpy array of floats
+        azimuths of rising/setting arcs
+    emin : float
+        minimum elevation angle, degrees
+    emax : float
+        maximum elevation angle, degrees
+    azriseset : ??
+        cannot remember
+    reqsamplerate : float
+        requested receiver sampling rate
+
+    """
+    # sample rate used for primary orbit calculation.  will scale by requested sample rate
+    samplerate = 30
+    # t is every five minutes
+    ie= interp1d(t, elev, kind='quadratic',bounds_error=False,fill_value='extrapolate')
+    ia= interp1d(t, azims, kind='quadratic',bounds_error=False,fill_value='extrapolate')
+    tnew = np.arange(t[0], t[-1], samplerate)
+    # interporlate el and az
+    enew = ie(tnew)
+    anew = ia(tnew)
+    # window it
+    i = (np.abs(anew-azriseset) < 20); enew = enew[i]
+    i = (enew >= emin) & (enew <= emax); enew = enew[i]
+    # scale factor for L1
+    cf = 0.1902936/2
+    N = len(enew)
+    if (N > 2):
+        maxe = max(enew); mine = min(enew)
+    # highest observation has to be within 0.5 degrees of requested
+        if ( maxe < (emax-0.5)):
+        #print(azriseset, 'max ele ', round(maxe,2), ' Not a significant arc')
+            nyq = np.nan
+        else:
+            diffT = (np.sin( maxe*np.pi/180) - np.sin(mine*np.pi/180) ) /cf
+    # we do 30 sec and then multiple by ratio of requested sample rate
+            nyq = round(N/(2*diffT),2)*(samplerate/reqsamplerate)
+    else:
+        nyq = np.nan
+
+    return nyq
+
+
+def calcAzEl_newish(prn, newf,recv,u,East,North):
+    """
+    should be consolidated with the other function.but who has the time!
+
+    Parameters
+    ----------
+    prn : int
+        satellite number ?
+
+    newf : 
+
+    u : numpy array
+        up unit vector
+    East: 
+
+    North : 
+
+    Returns
+    -------
+    tv : numpy array
+
+    """
+    tv = np.empty(shape=[0, 4])
+    # number of values
+    NV = len(newf)
+    for t in range(0,NV):
+        satv= [newf[t,2], newf[t,3],newf[t,4]]
+        etime = newf[t,1]
+        r=np.subtract(satv,recv) # satellite minus receiver vector
+        eleA = g.elev_angle(u, r)*180/np.pi
+        if ( (eleA >= 0) & (eleA <= 20)):
+            azimA = g.azimuth_angle(r, East, North)
+#            print(etime, eleA, azimA)
+            newl = [prn, eleA, azimA, etime]
+            tv = np.append(tv, [newl],axis=0)
+    nr,nc=tv.shape
+    return tv
+
