@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-"""
-"""
 import datetime
 import matplotlib.pyplot as plt
 import numpy as np
@@ -23,7 +20,6 @@ import gnssrefl.highrate as ch
 # fortran codes for translating RINEX
 import gnssrefl.gpssnr as gpssnr
 import gnssrefl.gnsssnr as gnsssnr
-
 import gnssrefl.gnsssnrbigger as gnsssnrbigger
 
 class constants:
@@ -62,14 +58,15 @@ def quickname(station,year,cyy, cdoy, csnr):
     return fname
 
 def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,archive,fortran,nol,overwrite,translator,srate,
-        mk,skipit,stream,strip,bkg):
+        mk,skipit,stream,strip,bkg,screenstats,gzip):
     """
-    main code to convert RINEX files into SNR files that are stored locally
+    main code to convert RINEX files into SNR files 
 
     Parameters
     ----------
-    station : string
+    station : str
         4 or 9 character station name. 6 ch allowed for japanese archive
+        9 means it is a RINEX 3 file
 
     year_list : list of int
         years to be analyzed
@@ -77,13 +74,13 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
     doy_list : list of integers
         doys to be analyzed
 
-    isnr : integer
+    isnr : int
         SNR file type choice
 
-    orbtype : string
+    orbtype : str
         orbit type, e.g. nav, rapid, gnss
 
-    rate : string
+    rate : str
         general sample rate.
         high: use 1-Hz area in the archive
         low: use default area in the archive
@@ -91,26 +88,26 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
     dec_rate : integer
          decimation value
 
-    archive : string
+    archive : str
         choice of GNSS archive
 
-    fortran : boolean
+    fortran : bool
         whether the fortran rinex translator is to be used
         default: false
 
-    nol: boolean
+    nol: bool
         True: assumes RINEX files are in local directory
         False (default): will look at multiple - or specific archive
 
-    overwrite: boolean
+    overwrite: bool
         False (default): if SNR file exists, SNR file not made
         True: make a new SNR file
 
-    translator : string
+    translator : str
         hybrid (default), fortran, or python
-        hybrid uses fortran within the python code
+        hybrid uses fortran within he python code
 
-    srate : integer
+    srate : int
         sample rate for RINEX 3 files
 
     mk : boolean
@@ -119,25 +116,26 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
     skipit : int
          skips making files every day, so a value of 7 means weekly.  1 means do every day
 
-    strip : boolean
+    strip : bool
          reduces observables to only SNR (too many observables, particularly in RINEX 2 files
          will break the RINEX translator)
 
     bkg : str
          location of bkg files, EUREF or IGS
 
+    screenstats: bool
+         whether print statements come to screen
+
+    gzip: bool
+         whether SNR files are gzipped after creation
     """
     #
-    if archive == 'special':
-        print('The special option needs to be updated for new UNAVCO/Earthscope protocols. Please submit ')
-        print('an issue at https://github.com/kristinemlarson/gnssrefl.')
     # do not allow illegal skipit values
     if skipit < 1:
         skipit = 1
 
     NS = len(station)
     if (NS == 4):
-        #print('Assume RINEX 2.11');
         version = 2
         if not mk:
             station = station.lower()
@@ -180,17 +178,28 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
 
         for doy in doy_list:
             csnr = str(isnr)
-            cdoy = '{:03d}'.format(doy) ; cyy = '{:02d}'.format(year-2000)
+            cdoy = '{:03d}'.format(doy)
+            if (year<2000):
+                cyy = '{:02d}'.format(year-1900)
+            else:
+                cyy = '{:02d}'.format(year-2000)
             # first, check to see if the SNR file exists
             fname =  quickname(station,year,cyy,cdoy,csnr)
             # now it unzips if that version exists
             snre = g.snr_exist(station,year,doy,csnr)
             if snre:
                 if overwrite:
-                    print('File exists, you requested overwriting, so will delete existing file')
-                    subprocess.call(['rm', fname]); snre = False
+                    print('File exists, ', fname, ' and you requested overwriting, so will delete existing file')
+                    if os.path.isfile(fname):
+                        subprocess.call(['rm', fname]); 
+                    if os.path.isfile(fname + '.gz'):
+                        subprocess.call(['rm', fname + '.gz']); 
+                    snre = False
                 else:
-                    print('SNR file already exists', fname)
+                    print('SNR file already exists', fname, '\n')
+            else:
+                print('SNR file does not already exist. Which means I will try to make it.')
+
 
             illegal_day = False
             if (doy > dec31):
@@ -201,17 +210,29 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
                 rgz = station + cdoy + '0.' + cyy + 'o.gz'
                 localpath2 =  os.environ['REFL_CODE'] + '/' + cyyyy + '/rinex/' + station + '/'
                 if nol:
-                    print('Will first assume RINEX file ', station, ' year:', year, ' doy:', doy, 'is in the local directory')
+                    current_local = os.getcwd()
+                    print('Will first assume RINEX file ', station, ' year:', year, ' doy:', doy, 'is located here :', current_local)
                     # this assumes RINEX file is in local directory or "nearby"
                     if version == 2:
+
                         if mk:
                             the_makan_option(station,cyyyy,cyy,cdoy) # looks everywhere in your local directories
                         if not os.path.exists(r):
+                            print('Did not find the plain observation file, so now trying other names/directories')
                             # could try this way? - look for file in localpath2. gunzip if necessary
                             allgood = get_local_rinexfile(r,localpath2)
                         if os.path.exists(r):
+                            rinext =float(np.loadtxt(r,usecols=0,dtype='str',max_rows=1))
+                            print('Apparent Rinex version', rinext)
+                            if (rinext != 2.11):
+                                print('Your file is not RINEX v2.11 which is what you told the code it was. Exiting')
+                                sys.exit()
+
+                            if screenstats:
+                                print('Found the RINEX 2.11 file', r)
                             if strip:
-                                print('Testing out stripping the RINEX 2 file here')
+                                if screenstats:
+                                    print('Testing out stripping the RINEX 2 file here')
                                 k.strip_rinexfile(r)
                             conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator)
                         else:
@@ -228,14 +249,36 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
                         r3gz = station9ch + streamid + str(year) + cdoy + '0000_01D_' + csrate + 'S_MO.rnx.gz'
                         r2 = station + cdoy + '0.' + cyy + 'o'
                         if os.path.exists(r3cmpgz):
-                            print('Try to translate', r3cmpgz)
+                            if screenstats: 
+                                print('Try to translate', r3cmpgz)
                             deletecrx = True
                             translated, rnx_filename = go_from_crxgz_to_rnx(r3cmpgz,deletecrx)
                         if os.path.exists(r3gz):
-                            print('Try to gunzip ', r3gz)
+                            if screenstats: 
+                                print('Try to gunzip ', r3gz)
                             subprocess.call(['gunzip', r3gz])
+
+                        # have not found the rinex 3 file
+                        if not os.path.exists(r3):
+                            local_rinex3_dir  = os.environ['REFL_CODE'] + '/' + cyyyy + '/rinex/' + station + '/'
+                            print('try looking for RINEX 3 in ', local_rinex3_dir)
+                            lrinex3 = local_rinex3_dir+r3
+                            if os.path.exists(lrinex3):
+                                subprocess.call(['cp', lrinex3, '.'])
+                            else:
+                                lrinex3 = local_rinex3_dir+r3cmpgz
+                                if os.path.exists(lrinex3):
+                                    subprocess.call(['cp', lrinex3, '.']); 
+                                    deletecrx = True
+                                    translated, rnx_filename = go_from_crxgz_to_rnx(r3cmpgz,deletecrx)
                         if os.path.exists(r3):
-                            print('The RINEX 3 file exists locally', r3)
+                            rinext =float(np.loadtxt(r3,usecols=0,dtype='str',max_rows=1))
+                            print('Apparent Rinex version', rinext)
+                            if (rinext < 3):
+                                print('Your file is not RINEX v3 or higher which is I was expecting. Exiting.')
+                                sys.exit()
+                            if screenstats: 
+                                print('The RINEX 3 file exists locally', r3)
                             # convert to RINEX 2.11
                             fexists = g.new_rinex3_rinex2(r3,r2,dec_rate)
                             if fexists:
@@ -243,11 +286,13 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
                             else:
                                 print('Something about the RINEX 3-2 conversion did not work')
                         else:
-                            print('You Chose the No Look Option, but did not provide the needed RINEX3 file.')
-                            print('I assumed its name was ', r3)
+                            print('You Chose the No Look Option, but did not provide the needed RINEX3 file ', r3)
+                            print('I looked for files ending with rnx, rnx.gz, and crx.gz in the local directory')
+                            print('I looked for files ending with rnx and crx.gz in $REFL_CODE/YYYY/rinex for your station')
 
                 else:
-                    print('Will seek the RINEX file from an external archive')
+                    if screenstats:
+                        print('Will seek the RINEX file from an external archive')
                     if version == 3:
                         fexists = False
                         rnx_filename = '' # just in  case?
@@ -255,29 +300,52 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
                         r2 = station + cdoy + '0.' + cyy + 'o'
                         rinex2exists = False; rinex3name = '';
                         if (rate == 'high'):
-                            print('This code only accesses 1-Hz Rinex 3 data at CDDIS, BKG, and GA')
+                            print('This code only accesses 1-Hz Rinex 3 data at BKG, CDDIS, and GA')
                             if archive == 'ga':
                                 deleteOld = True
                                 # cold should return the new name of the rinex 2 file
                                 r2, foundit = g.ga_highrate(station9ch,year,doy,dec_rate,deleteOld)
-                                if foundit:
+                                if foundit and screenstats:
                                     print('rinex2 file should now exist:', r2)
                             if archive == 'cddis':
-                                rnx_filename,foundit = ch.cddis_highrate(station9ch, year, doy, 0,stream,dec_rate)
+                                bad_day = g.cddis_restriction(year, doy,'cddis')
+                                if not bad_day:
+                                    rnx_filename,foundit = ch.cddis_highrate(station9ch, year, doy, 0,stream,dec_rate)
+                                else: 
+                                    print('No high-rate RINEX data will be downloaded')
+                                    foundit = False; fexists = False; rnx_file = ''
                                 if foundit:
-                                    print('The RINEX 3 file has been downloaded. Try to make ', r2)
+                                    if screenstats:
+                                        print('The RINEX 3 file has been downloaded from CDDIS . Try to make ', r2)
                                     fexists = g.new_rinex3_rinex2(rnx_filename,r2,dec_rate)
                             if archive == 'bkg':
-                                rnx_filename,foundit = ch.bkg_highrate(station9ch, year, doy, 0,stream,dec_rate,bkg)
+                                bad_day = g.cddis_restriction(year, doy,'bkg')
+                                if not bad_day:
+                                    rnx_filename,foundit = ch.bkg_highrate(station9ch, year, doy, 0,stream,dec_rate,bkg)
+                                else:
+                                    print('No high-rate RINEX data will be downloaded')
+                                    foundit = False; fexists = False; rnx_file = ''
                                 if foundit:
-                                    print('The RINEX 3 file has been downloaded and merged. Try to make ', r2)
+                                    if screenstats:
+                                        print('The RINEX 3 file has been downloaded from the BKG and merged. Try to make ', r2)
+                                    fexists = g.new_rinex3_rinex2(rnx_filename,r2,dec_rate)
+                            if archive == 'ignes':
+                                bad_day = g.cddis_restriction(year, doy,'bkg')
+                                if not bad_day:
+                                    rnx_filename,foundit = ch.esp_highrate(station9ch, year, doy, 0,stream,dec_rate)
+                                else:
+                                    print('No high-rate RINEX data will be downloaded')
+                                    foundit = False; fexists = False; rnx_file = ''
+                                if foundit:
+                                    if screenstats:
+                                        print('The RINEX 3 file has been downloaded from IGN ES and merged. Try to make ', r2)
                                     fexists = g.new_rinex3_rinex2(rnx_filename,r2,dec_rate)
 
                         else:
                             if (archive == 'all'):
-                                file_name,foundit = k.universal_all(station9ch, year, doy,srate,stream)
+                                file_name,foundit = k.universal_all(station9ch, year, doy,srate,stream,screenstats)
                                 if (not foundit): # try again
-                                    file_name,foundit = k.universal_all(station9ch, year, doy, srate,k.swapRS(stream))
+                                    file_name,foundit = k.universal_all(station9ch, year, doy, srate,k.swapRS(stream),screenstats)
                             else:
                                 #print('stream',stream)
                                 file_name,foundit = k.universal(station9ch, year, doy, archive,srate,stream)
@@ -289,18 +357,20 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
                                 translated, rnx_filename = go_from_crxgz_to_rnx(file_name,deletecrx)
                             # now make rinex2
                                 if translated:
-                                    print('The RINEX 3 file has been downloaded. Try to make ', r2)
+                                    if screenstats:
+                                        print('The RINEX 3 file has been downloaded. Try to make ', r2)
                                     fexists = g.new_rinex3_rinex2(rnx_filename,r2,dec_rate)
                                     #subprocess.call(['rm', '-f',rnx_filename]) # rnx
                         # this means the rinex 2 version exists
                         if fexists:
-                             print('RINEX 2 created from v3', year, doy, ' Now remove RINEX 3 files and convert')
+                             if screenstats:
+                                 print('RINEX 2 created from v3', year, doy, ' Now remove RINEX 3 files and convert')
                              subprocess.call(['rm', '-f',rnx_filename]) # rnx
                              conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator)
                         else:
                             print('Unsuccessful RINEX 3 retrieval/translation', year, doy)
                     else:
-                        print(station, ' year:', year, ' doy:', doy, 'from: ', archive)
+                        print(station, ' year:', year, ' doy:', doy, ' from: ', archive, ' rate:', rate, ' orb:', orbtype)
                         # this is rinex version 2 - finds rinex and converts it
                         conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator)
 
@@ -339,6 +409,7 @@ def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,f
          hybrid, python, or fortran
 
     """
+    screenstats = False # for now
     # define directory for the conversion executables
     if not os.path.isdir('logs'):
         subprocess.call(['mkdir', 'logs'])
@@ -349,7 +420,16 @@ def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,f
     log.write("Archive: {0:10s} \n".format(archive))
     log.write("Orbits : {0:10s} \n".format(orbtype))
     exedir = os.environ['EXE']
-    snrname_full, snrname_compressed, snre = g.define_and_xz_snr(station,year,doy,option)
+    csnr = str(option)
+    cdoy = '{:03d}'.format(doy)
+    cyy = str(year)[2:4]
+    snrname_full =  quickname(station,year,cyy,cdoy,csnr)
+    print('Creating ', snrname_full)
+    snrname_compressed = ''
+
+    # if it exists, you should not have gotten to this code...
+    snre = False
+    #snrname_full, snrname_compressed, snre = g.define_and_xz_snr(station,year,doy,option)
     if (snre == True):
         log.write("The snrfile already exists: {0:50s} \n".format(snrname_full))
         print("The snrfile already exists: ", snrname_full)
@@ -368,17 +448,17 @@ def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,f
             # an archive preference
             if receiverrate == 'high':
                 strip_snr = False # for now -
+                #print('trying to find highrate file')
                 file_name, foundit = k.rinex2_highrate(station, year, doy,archive,strip_snr)
             else:
                 # added karnak librariies
                 if (archive == 'all'):
                     foundrinex = False
-                    # sopac put before unavco
-                    for archivechoice in ['sopac','unavco','sonel']:
+                    for archivechoice in ['unavco','sopac','sonel']:
                         if (not foundrinex):
-                            file_name,foundrinex = k.universal_rinex2(station, year, doy, archivechoice)
+                            file_name,foundrinex = k.universal_rinex2(station, year, doy, archivechoice,screenstats)
                 else:
-                    file_name,foundrinex = k.universal_rinex2(station, year, doy, archive)
+                    file_name,foundrinex = k.universal_rinex2(station, year, doy, archive,screenstats)
 
                 if foundrinex: #uncompress etc  to make o files ...
                     rinexfile, foundit2 = k.make_rinex2_ofiles(file_name) # translate
@@ -426,7 +506,7 @@ def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,f
                     if (orbtype  == 'gps') or ('nav' in orbtype):
                         gpssnr.foo(in1,in2,in3,in4,in5,in6)
                     else:
-                        if (orbtype == 'ultra') or (orbtype == 'wum'):
+                        if orbtype in ['ultra', 'wum', 'wum2']:
                             print('Using an ultrarapid orbit', orbtype)
                             gnsssnrbigger.foo(in1,in2,in3,in4,in5,in6)
                         else:
@@ -466,12 +546,15 @@ def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,f
                         log.write('bad exe, bad snr option, do not really have the orbit file \n')
                         status = subprocess.call(['rm','-f', snrname ])
                     else:
-                        log.write('A SNR file was created: {0:50s}  \n'.format(snrname_full))
+                        log.write('A SNR file was created : {0:50s}  \n'.format(snrname_full))
                         print('\n')
-                        print('SUCCESS: SNR file was created:', snrname_full)
+                        print('SUCCESS: SNR file was created \n', snrname_full)
                         g.store_snrfile(snrname,year,station)
+                        subprocess.call(['gzip', snrname_full])
+
                 else:
-                    print('No SNR file was created - check logs section for additional information')
+                    logfile = 'logs/' + station + '_hybrid_error.txt'
+                    print('No SNR file created - check ', logfile, ' for why it failed.')
             else:
                 print('Either the RINEX file or orbit file does not exist, so there is nothing to convert')
                 log.write('Either the RINEX file or orbit file does not exist, so there is nothing to convert \n')
@@ -564,12 +647,12 @@ def rnx2snr(obsfile, navfile,snrfile,snroption,year,month,day,dec_rate,log):
         kind of SNR file requested
 
     year : int
-
+        full year
     month : int
-
+        calendar month
     day : int
-
-    dec_rate : integer
+        calendar day
+    dec_rate : int
         decimation rate in seconds
 
     """
@@ -1113,17 +1196,21 @@ def the_makan_option(station,cyyyy,cyy,cdoy):
     #so_many_permutations(r,rd,locdir, crnxpath)
 
     if os.path.exists(r):
+        #print('type 1')
         missing = False
 
     if os.path.exists(r + '.gz') and missing:
+        #print('type 2')
         subprocess.call(['gunzip', r + '.gz'])
         missing = False
 
     if os.path.exists(r + '.Z') and missing:
+        #print('type 3')
         subprocess.call(['uncompress', r + '.Z'])
         missing = False
 
     if os.path.exists(rd) and missing:
+        #print('type 4')
         if os.path.exists(crnxpath):
             subprocess.call([crnxpath,rd])
             subprocess.call(['rm',rd])
@@ -1132,6 +1219,7 @@ def the_makan_option(station,cyyyy,cyy,cdoy):
             g.hatanaka_warning(); return
 
     if os.path.exists(rd + '.gz') and missing:
+        #print('type 5')
         subprocess.call(['gunzip', rd + '.gz'])
         if os.path.exists(crnxpath):
             subprocess.call([crnxpath,rd])
@@ -1141,6 +1229,7 @@ def the_makan_option(station,cyyyy,cyy,cdoy):
             g.hatanaka_warning();
 
     if os.path.exists(rd + '.Z') and missing:
+        #print('type 6')
         subprocess.call(['uncompress', rd + '.Z'])
         if os.path.exists(crnxpath):
             subprocess.call([crnxpath,rd])
@@ -1150,10 +1239,12 @@ def the_makan_option(station,cyyyy,cyy,cdoy):
             g.hatanaka_warning()
 
     if os.path.exists(locdir + r) and missing:
+        #print('type 7')
         subprocess.call(['cp', '-f',locdir + r,'.'])
         missing = False
 
     if os.path.exists(locdir + r + '.gz') and missing:
+        #print('type 8')
         subprocess.call(['cp', '-f',locdir + r + '.gz' ,'.'])
         subprocess.call(['gunzip', r + '.gz'])
         missing = False
@@ -1173,6 +1264,7 @@ def the_makan_option(station,cyyyy,cyy,cdoy):
             g.hatanaka_warning();
 
     if os.path.exists(locdir + rd + '.Z') and missing:
+        print('here?')
         subprocess.call(['cp','-f',locdir + rd + '.Z','.'])
         subprocess.call(['uncompress', rd + '.Z'])
         if os.path.exists(crnxpath):
@@ -1231,44 +1323,119 @@ def go_from_crxgz_to_rnx(c3gz,deletecrx=True):
     if os.path.exists(rnx): # file exists
         translated = True
         if deletecrx:
-            print('remove Hatanaka compressed file')
+            #print('remove Hatanaka compressed file')
             subprocess.call(['rm','-f',c3])
 
     return translated, rnx
 
 def get_local_rinexfile(rfile,localpath2):
     """
-    look for a plain or gzipped version of the rinex 2.11 file in the year subdirectories
+    look for a plain or gzipped version of the RINEX 2.11 file in the year subdirectories
     copies it to the local directory.  this method stops the code from deleting your rinex 
-    files
+    files. As of 2023 September 19, it should also look for Hatanaka files.
 
     localpath2 =  os.environ['REFL_CODE'] + '/' + cyyyy + '/rinex/' + station + '/'
 
+    This is unlikely to work for uppercase RINEX files. Try the mk option
+
     Parameters
     ----------
     rfile : str
         version2 rinexfile name
 
     localpath2 : str
-        location of the file
+        another location of the file (meant to be as defined above)
 
     Returns
     -------
     allgood : bool
         whether file found
     """
+    crnxpath = g.hatanaka_version()
     allgood = False
-    r = localpath2 + rfile
-    if os.path.exists(r):
+    # hatanaka filename has d at end instead of o
+    rd = rfile[0:-1] + 'd'
+
+    # look for gzip version in local directory first
+    if os.path.exists(rfile + '.gz'):
+        print('found ', rfile + '.gz')
+        subprocess.call(['gunzip', rfile + '.gz'])
         allgood = True
-        # cp to the local directory
-        subprocess.call(['cp',r,'.'])
-    else:
-       # did not find noromal rinex, so look for gzip version
-        if os.path.exists(r + '.gz'):
-            subprocess.call(['gunzip', r + '.gz'])
+
+
+    # then look for unix compressed version local directory 
+    if os.path.exists(rfile + '.Z') and not allgood:
+        print('found ', rfile + '.Z')
+        subprocess.call(['uncompress', rfile + '.Z'])
+        allgood = True 
+
+    # then look for hatanaka compressed version local directory 
+    if os.path.exists(rd) and not allgood:
+        print('found ', rd)
+        if os.path.exists(crnxpath):
+            subprocess.call([crnxpath,rd])
+            if os.path.exists(rfile):
+                allgood = True
+                subprocess.call(['rm',rd])
+
+    # then look for hatanaka compressed and unix compressed version local directory 
+    if os.path.exists(rd + '.Z') and not allgood:
+        print('found ', rd + '.Z')
+        if os.path.exists(crnxpath):
+            subprocess.call(['uncompress', rd + '.Z'])
+            subprocess.call([crnxpath,rd])
+            if os.path.exists(rfile):
+                allgood = True
+                subprocess.call(['rm',rd])
+
+    # now check in 
+    if not allgood:
+        print('Checking for the file in : ', localpath2)
+        r = localpath2 + rfile
+        # hatanaka version in REFL_CODE
+        rdd = localpath2 + rd
+
         if os.path.exists(r):
-            subprocess.call(['cp',r,'.'])
             allgood = True
+        # cp to the local directory
+            print('copying RINEX file to local area')
+            subprocess.call(['cp',r,'.'])
+        else:
+       # did not find normal rinex, so look for gzip version
+            if os.path.exists(r + '.gz'):
+                subprocess.call(['gunzip', r + '.gz'])
+                if os.path.exists(r):
+                    print('copying RINEX file to local area')
+                    subprocess.call(['cp',r,'.'])
+                    # now gzip the original file ...
+                    subprocess.call(['gzip', r ])
+                    allgood = True
+            # if hatanaka is stored locally
+            if os.path.exists(rdd) and not allgood:
+                # copy from REFL_CODE to local dir
+                # and convert
+                print('copying Hatanaka file to local area')
+                subprocess.call(['cp',rdd,'.'])
+                subprocess.call([crnxpath,rd])
+                if os.path.exists(rfile):
+                    allgood = True
+                    subprocess.call(['rm',rd])
 
     return allgood
+
+def print_archives():
+    """
+    feeble attempt to print list of archives to screen ...
+
+    """
+    archive_list_rinex3 = ['unavco', 'cddis', 'bev', 'bkg', 'ga', 'epn', 'bfg','sonel','all','unavco2','nrcan','gfz','ignes']
+    archive_list = ['sopac', 'unavco', 'sonel',  'nz', 'ga', 'bkg', 'jeff',
+                    'ngs', 'nrcan', 'special', 'bev', 'jp', 'all','unavco2','cddis']
+    w = 'RINEX 3 archives '
+    for i in range(0,len(archive_list_rinex3)):
+        w = w + archive_list_rinex3[i] + ' '
+    w = w + '\n RINEX 2.11 archives '
+    for i in range(0,len(archive_list)):
+        w = w + archive_list[i] + ' '
+    msg = w
+    return msg
