@@ -1,9 +1,9 @@
-import numpy as np
 from astropy.time import Time
 from astropy.timeseries import LombScargle
 import datetime
 import math
 import matplotlib.pyplot as plt
+import numpy as np
 import os
 import pickle
 from scipy import interpolate
@@ -59,6 +59,8 @@ def readklsnrtxt(snrfile, thedir, signal):
     The file itself is read in a separate function now; 
     if SNR data are zero for a given signal, the row is eliminated
 
+    As of Oct 28, 2023, gzip after reading SNR file
+
     Parameters
     ----------
     snrfile: str
@@ -81,6 +83,7 @@ def readklsnrtxt(snrfile, thedir, signal):
     """
     # do a straight load of the file
     snrall = loadsnrfile(snrfile, thedir)
+    subprocess.call(['gzip', thedir + snrfile])
 
     nr,nc = snrall.shape
     # this is for the frequency information
@@ -176,7 +179,7 @@ def readklsnrtxt(snrfile, thedir, signal):
 
     # remove the zeroes
     ii = (snrdata[:,4] != 0)
-    print('Num of obs before ', len(snrdata))
+    #print('Num of obs before ', len(snrdata))
     snrdata = snrdata[ii,:]
     print('Num of non-zero obs ', len(snrdata))
 
@@ -280,6 +283,7 @@ def snr2arcs(station,snrdata, azilims, elvlims, rhlims, precision, year,doy,sign
     reads an array of snr data (output from readklsnrtxt) and organises into:
     reflector height estimates, stats and detrended snr data for inverse analysis
 
+
     Parameters
     ----------
     station : str
@@ -336,11 +340,13 @@ def snr2arcs(station,snrdata, azilims, elvlims, rhlims, precision, year,doy,sign
         detrended SNR data for inverse analysis
 
     """
+    print('screen stats', screenstats)
     # get a list for late ron
     if 'l2c_only' in kwargs:
         l2c_only = kwargs.get('l2c_only')
-    if l2c_only:
-        print('For L2, only use L2c ')
+    # no need to print to screen
+    #if l2c_only:
+    #    print('For L2, only use L2c ')
 
     # get the list
     l2clist,l5list = l2c_l5_list(year,doy)
@@ -362,7 +368,7 @@ def snr2arcs(station,snrdata, azilims, elvlims, rhlims, precision, year,doy,sign
             snrdata = snrdata[tfilter]
             print('Num of obs after decimation', len(snrdata))
 
-    print('sat consts before if statement', satconsts)
+    #print('sat consts before if statement', satconsts)
     # remove satellite data from non-requested constellations
     if 'satconsts' in kwargs:
         satconsts = kwargs.get('satconsts')
@@ -383,7 +389,7 @@ def snr2arcs(station,snrdata, azilims, elvlims, rhlims, precision, year,doy,sign
     if 'C' not in satconsts:
         nogal = np.logical_or(snrdata[:, 0] < 300, snrdata[:, 0] > 400)
         snrdata = snrdata[nogal]
-        print('Num of obs after Beidou removal', len(snrdata))
+        #print('Num of obs after Beidou removal', len(snrdata))
 
     # apply elevation and azimuth restrictions.   
     # KL: we usually do the DC first and then apply the restrictions DC  
@@ -397,7 +403,7 @@ def snr2arcs(station,snrdata, azilims, elvlims, rhlims, precision, year,doy,sign
     snrdata = snrdata[tfilter]
     print('Apply azimuth angle filter: ', azilims[0], azilims[1])
 
-    print('Using Lomb Scargle precision of ', precision, ' m')
+    #print('Using Lomb Scargle precision of ', precision, ' m')
     # setting up arrays for the output of the LSP
     # changed this to 12 to accommodate frequency
     #rh_arr = np.empty((0, 11))
@@ -416,11 +422,11 @@ def snr2arcs(station,snrdata, azilims, elvlims, rhlims, precision, year,doy,sign
     #if signal not in ['L1','L2','L5','L1+L2','L1+L5','L1+L2+L5','L1+L6','L6','L1+L2+L6','L1+L2+L5+L6']:
     #    print('code only currently works for L1, L2, L5, L6, and combinations therein- exiting')
     #    sys.exit()
-    print('Satellites:')
+    #print('Satellites:')
     satellite_list = np.unique(snrdata[:,0]); 
-    print(satellite_list)
+    #print(satellite_list)
     signal_list = signal2list(signal)
-    print('Frequencies: ', signal_list)
+    #print('Frequencies: ', signal_list)
     # make a dictionary to keep track of the constellation/frequencies that are being used
     alld = {}
     # initialize values?
@@ -438,7 +444,8 @@ def snr2arcs(station,snrdata, azilims, elvlims, rhlims, precision, year,doy,sign
         # added this so i can loop through more than one frequency.  hopefully
         for xsignal in signal_list:
             isignal = int(xsignal[1:2]) # integer version of frequency
-            #print('Working on satellite/signal:', int(sat),xsignal,isignal)
+            if screenstats:
+                print('Working on satellite/signal:', int(sat),xsignal,isignal)
 
             # frequency (integer) should be in column "5"
             sfilter = (first_tempd[:, 5] == isignal)
@@ -493,10 +500,17 @@ def snr2arcs(station,snrdata, azilims, elvlims, rhlims, precision, year,doy,sign
                 ddate = np.ediff1d(date_tosort)
                 delv = np.ediff1d(elv_tosort)
                 bkpt = len(ddate)
+
                 bkpt = np.append(bkpt, np.where(ddate > gaptlim)[0])  # gaps bigger than gaptlim
+                if screenstats:
+                    print('gaps',len(bkpt))
                 bkpt = np.append(bkpt, np.where(np.diff(np.sign(delv)))[0])  # elevation rate changes direction
+                if screenstats:
+                    print('gaps from ostensible elevation rate changes',len(bkpt))
                 bkpt = np.unique(bkpt)
                 bkpt = np.sort(bkpt)
+                if screenstats:
+                    print('Number of arcs for this satellite?', len(bkpt))
                 for ii in range(len(bkpt)):
                     if ii == 0:
                         sind = 0
@@ -508,7 +522,7 @@ def snr2arcs(station,snrdata, azilims, elvlims, rhlims, precision, year,doy,sign
                         continue
                     elvt = np.array(tempd[sind:eind, 1], dtype=float)
                     if len(np.unique(elvt)) == 1:
-                #print('unchanging elevation')
+                        print('unchanging elevation')
                         continue
                     azit = np.array(tempd[sind:eind, 2], dtype=float) # azimuth array
                     sinelvt = np.sin(elvt / 180 * np.pi) # sine elevation angle array
@@ -521,7 +535,7 @@ def snr2arcs(station,snrdata, azilims, elvlims, rhlims, precision, year,doy,sign
                 # frequency, and thus RH
                     snrdt = snrt - p(sinelvt)
                     pgram = LombScargle(sinelvt, snrdt, normalization='psd').power(f)
-
+                    pgram = 2 * np.sqrt(pgram/len(sinelvt))
                 # converting it into the proper units of RH (meters)
                     reflh = 0.5 * f * lcar
                 # this is a very simplistic outlier detector
@@ -532,11 +546,12 @@ def snr2arcs(station,snrdata, azilims, elvlims, rhlims, precision, year,doy,sign
                 # KL pktn = np.max(pgram_sub) / np.mean(pgram)
                     pktn = np.max(pgram_sub) / np.mean(pgram_sub)
 
-                # compute LSP with my code
 
                     maxF, maxA,peak2noise = simpleLSP(rhlims, lcar, precision,
                             elvt, sinelvt, snrdt,sat,xsignal,screenstats,fout,pktnlim)
 
+
+                    #print('new', pktn, 'limit',pktnlim, 'old',np.max(pgram_sub) / np.mean(pgram))
                     if maxind != 0 and maxind != len(pgram_sub) - 1 and pktn > pktnlim:  # no peaks at either end of window
                         # KL moved this to a function/added a column to save frequency information
                         temp_arr = save_lsp_results(datet,maxind,reflh_sub,sat,elvt,azit,pgram_sub,snrdt,pktn,isignal)
@@ -763,8 +778,8 @@ def snr2spline(station,year,doy, azilims, elvlims,rhlims, precision, kdt, snrfit
         if lsp['refraction']:
             imodel = 1 #
         dmjd = 59580 # fake number
-        p,T,irefr = set_refraction_model(station, dmjd,lsp,imodel)
-        print('refraction parameters ', p,T,irefr)
+        p,T,irefr,humidity = set_refraction_model(station, dmjd,lsp,imodel)
+        #print('refraction parameters ', p,T,humidity,irefr)
 
     if 'rough_in' in kwargs:
         rough_in  = kwargs.get('rough_in')
@@ -788,6 +803,7 @@ def snr2spline(station,year,doy, azilims, elvlims,rhlims, precision, kdt, snrfit
     if 'outlier_limit' in kwargs:
         outlier_limit = kwargs.get('outlier_limit')
 
+    # default is 66 - originally I think david had it as a string?  
     snr_ending = 66
     if 'snr_ending' in kwargs:
         snr_ending = kwargs.get('snr_ending')
@@ -824,7 +840,7 @@ def snr2spline(station,year,doy, azilims, elvlims,rhlims, precision, kdt, snrfit
     nr,nc = snrdata.shape
     print('Number of obs', nr, ' number of days', numdays)
     if imodel == 1:
-        print('Modifying elevation angles for a simple refraction correction')
+        #print('Modifying elevation angles for a simple refraction correction')
         #print('Elevation angle before ', snrdata[0,1])
         correctedE = refr.corr_el_angles(snrdata[:,1], p,T)
         snrdata[:,1] = correctedE
@@ -837,20 +853,20 @@ def snr2spline(station,year,doy, azilims, elvlims,rhlims, precision, kdt, snrfit
     print(stryday)
     tobj = Time(stryday, format='yday')
     gbase = tobj.gps
-    print('>>>>  gbase value', gbase)
+    #print('>>>>  gbase value', gbase)
     # Setting up knots ...
     knots = np.linspace(gbase + int(kdt/2), gbase + numdays*86400 - int(kdt/2), int(numdays*86400/kdt))
-    print('Here be the knots:', knots)
+    #print('Here be the knots:', knots)
     print('Knot spacing in seconds ',int(kdt/2))
     print('Number of knots',int(numdays*86400/kdt))
     knots = np.append(gbase, knots)  # add start and end of day for more stable output but dont use these points
     knots = np.append(knots, gbase + numdays*86400)
 
 
-    print('Sorting snr data into arcs')
+    #print('Sorting snr data into arcs')
 
     # arguments sent directly
-    print('Begin Lomb Scargle analysis')
+    #print('Begin Lomb Scargle analysis')
     s1=time.time()
     rh_arr, snrdt_arr, fspecdict= snr2arcs(station,snrdata, azilims, elvlims, rhlims, precision, year, doy, signal=signal,**kwargs)
     # should already exist
@@ -860,7 +876,7 @@ def snr2spline(station,year,doy, azilims, elvlims,rhlims, precision, kdt, snrfit
     #    subprocess.call(['mkdir',xdir])
     s2=time.time()
     print('Time spent: ',round(s2-s1,2), ' seconds')
-    print(fspecdict)
+    #print(fspecdict)
     print('Found ' + str(np.ma.size(rh_arr, axis=0)) + ' arcs')
     if screenstats:
         print(' RH(m)  Sat  Azim  Dt  Pk2noise Freq  Hours since epoch0')
@@ -909,40 +925,40 @@ def snr2spline(station,year,doy, azilims, elvlims,rhlims, precision, kdt, snrfit
         residuals = residuals_cubspl_spectral(kval, knots, rh_arr)
         return residuals
 
-    print('Now fitting a cubic spline to the arcs with rhdot included?')
+    #print('Now fitting a cubic spline to the arcs but rhdot not included')
     kval_0 = np.nanmean(rh_arr[:, 1]) * np.ones(len(knots))
-    print('Number of knots here ', len(knots))
+    #print('Number of knots used in ', len(knots))
     s1=time.time()
     ls_spectral = least_squares(residuals_spectral_ls, kval_0, method='trf', bounds=rhlims)
     kval_spectral = ls_spectral.x
-    print('Length of kval_spectral', len(kval_spectral))
+    #print('Length of kval_spectral', len(kval_spectral))
     invout['knots'] = knots
     invout['kval_spectral'] = kval_spectral[1:-1]  # dont save first and last points
     s2=time.time()
-    print(round(s2-s1,2), ' seconds')
+    #print('Fitting spline to LSP results took ', round(s2-s1,2), ' seconds')
     print('satellite constellations ', satconsts)
     if snrfit:
         s1=time.time()
-        print('Now doing Joakim Strandberg SNR fitting inversion')
+        #print('Now doing Joakim Strandberg SNR fitting inversion')
         kval_0 = kval_spectral
-        print('kval_0', kval_0)
+        #print('kval_0', kval_0) dont need to print htis out
         final_list, Nfreq = smarterWay(fspecdict)
         print(final_list)
-        print('Number of constellation specific frequencies', Nfreq)
+        #print('Number of constellation specific frequencies', Nfreq)
         # consts = len(satconsts)
         #kval_0 = np.append(kval_0, np.zeros(consts * 2))
         # this should be correct .... wont 
         kval_0 = np.append(kval_0, np.zeros(Nfreq* 2))
-        print('Roughness', rough_in)
+        #print('Roughness', rough_in)
         kval_0 = np.append(kval_0, rough_in)
 
         aa,bb = snrdt_arr.shape
-        print('Dimensions of the snrdt_arr variable', aa,bb)
-        print('Now sending it ', Nfreq, ' different constellation specific frequencies')
+        #print('Dimensions of the snrdt_arr variable', aa,bb)
+        #print('Now sending it ', Nfreq, ' different constellation specific frequencies')
         def residuals_js_ls(inparam):
             residuals = residuals_cubspl_js(inparam, knots, satconsts, signal, snrdt_arr,final_list,Nfreq)
             return residuals
-        print('Calling the least squares code')
+        #print('Calling the least squares code')
         ls_js = least_squares(residuals_js_ls, kval_0, method='lm')
         invout_js = ls_js.x
         kval_js = invout_js[:len(knots)]
@@ -950,7 +966,7 @@ def snr2spline(station,year,doy, azilims, elvlims,rhlims, precision, kdt, snrfit
         invout['kval_js'] = kval_js[1:-1]  # dont save first and last points
         invout['outparams_js'] = outparams_js
         s2 = time.time()
-        print('Time spend in snrfit', round(s2-s1,2), ' seconds')
+        print('Time spent in snrfit', round(s2-s1,2), ' seconds')
 
     if True:
         delta_out = 300 # seconds
@@ -1069,21 +1085,21 @@ def invsnr_header(xdir, outfile_type,station,outfile_name):
 
     Parameters
     ----------
-    xdir : string 
+    xdir : str
         directory for the output file
-    outfile_type : string
+    outfile_type : str
         csv or txt
-    station : string
+    station : str
         4 character name
-    outfile_name : string
-        name of output - if '', it uses default
+    outfile_name : str
+        name of output - if empty string, it uses default
 
     Returns 
     -------
-    fileID : ? 
+    fileID : file
         used for writing to file
-    usetxt : boolean
-        - boolean for the code calling this function to use
+    usetxt : bool
+        boolean for the code calling this function to use
         if you write out special files, they go in the working directory
 
     """
@@ -1118,33 +1134,34 @@ def define_inputfile(station,year,doy,snr_ending):
 
     Parameters
     ----------
-    station : string
+    station : str
         4 ch name of station 
     year : integer
 
-    doy : integer
+    doy : int
         day of year 
 
-    snr_ending : integer
+    snr_ending : int
         file ending, e.g. 66, 99
 
     Returns
     -------
-    snrfile: string
+    snrfile: str
         name of snrfile 
 
-    snrdir : string
+    snrdir : str
         name of output directory
 
-    cyyyy : string
+    cyyyy : str
         four character year
 
-    cdoy : string
+    cdoy : str
         three character day of year
     """
     cdoy = '{:03d}'.format(doy) ;
-    cyy = '{:02d}'.format(year-2000)
     cyyyy = str(year)
+    cyy = cyyyy[2:4]
+
     xdir = os.environ['REFL_CODE'] + '/' + cyyyy + '/snr/' + station + '/'
     snrfile = station + cdoy + '0.' + cyy + '.snr' + str(snr_ending)
     gzfile = xdir + snrfile + '.gz'
@@ -1158,12 +1175,12 @@ def define_inputfile(station,year,doy,snr_ending):
         # look for gzipped file
         elif os.path.isfile(gzfile):
             # unzip it, declare success
-            print('Found gzipped version', snrfile)
+            #print('Found gzipped version', snrfile)
             subprocess.call(['gunzip',gzfile])
             snrdir = xdir
         elif os.path.isfile(xzfile):
             # unxz it, declare success
-            print('Found xz version', snrfile)
+            #print('Found xz version', snrfile)
             subprocess.call(['unxz',xzfile])
             snrdir = xdir
         else:
@@ -1684,6 +1701,9 @@ def set_refraction_model(station, dmjd,lsp,imodel):
     imodel is 1 for simple refraction model
     eventually will add other refraction models
 
+    Looks like this was copied from other code and should be
+    consolidated ...
+
     Parameters
     ----------
     station : str
@@ -1703,11 +1723,13 @@ def set_refraction_model(station, dmjd,lsp,imodel):
         temperature in deg C
     irefr : int
         number value written to output files to keep track of refraction model
+    e : float
+        water vapor pressure, hPa
 
     """
     xdir = os.environ['REFL_CODE']
     p = 0; T = 0; irefr = 0
-    print(lsp['lat'], lsp['lon'])
+    #print(lsp['lat'], lsp['lon'])
     if (imodel == 1):
         irefr = 1
         refr.readWrite_gpt2_1w(xdir, station, lsp['lat'], lsp['lon'])
@@ -1717,5 +1739,5 @@ def set_refraction_model(station, dmjd,lsp,imodel):
         p,T,dT,Tm,e,ah,aw,la,undu = refr.gpt2_1w(station, dmjd,dlat,dlong,ht,it)
         #print("Pressure {0:8.2f} Temperature {1:6.1f} \n".format(p,T))
 
-    return p,T,irefr
+    return p,T,irefr, e
 
